% Auto-generated chapter 93 for bukhari
% Hadiths in this chapter: 84

\hadithdefcmd{bukhari}{7137}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَطَاعَنِي فَقَدْ أَطَاعَ اللَّهَ، وَمَنْ عَصَانِي فَقَدْ عَصَى اللَّهَ، وَمَنْ أَطَاعَ أَمِيرِي فَقَدْ أَطَاعَنِي، وَمَنْ عَصَى أَمِيرِي فَقَدْ عَصَانِي ‏"‏‏.‏\hadithno{7137}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Whoever obeys me, obeys Allah, and whoever disobeys me, disobeys Allah, and whoever obeys the ruler I appoint, obeys me, and whoever disobeys him, disobeys me}}
\hadithdefcmd{bukhari}{7138}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَلاَ كُلُّكُمْ رَاعٍ، وَكُلُّكُمْ مَسْئُولٌ عَنْ رَعِيَّتِهِ، فَالإِمَامُ الَّذِي عَلَى النَّاسِ رَاعٍ وَهْوَ مَسْئُولٌ عَنْ رَعِيَّتِهِ، وَالرَّجُلُ رَاعٍ عَلَى أَهْلِ بَيْتِهِ وَهْوَ مَسْئُولٌ عَنْ رَعِيَّتِهِ، وَالْمَرْأَةُ رَاعِيَةٌ عَلَى أَهْلِ بَيْتِ زَوْجِهَا وَوَلَدِهِ وَهِيَ مَسْئُولَةٌ عَنْهُمْ، وَعَبْدُ الرَّجُلِ رَاعٍ عَلَى مَالِ سَيِّدِهِ وَهْوَ مَسْئُولٌ عَنْهُ، أَلاَ فَكُلُّكُمْ رَاعٍ وَكُلُّكُمْ مَسْئُولٌ عَنْ رَعِيَّتِهِ ‏"‏‏.‏\hadithno{7138}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "Surely! Everyone of you is a guardian and is responsible for his charges: The Imam (ruler) of the people is a guardian and is responsible for his subjects; a man is the guardian of his family (household) and is responsible for his subjects; a woman is the guardian of her husband's home and of his children and is responsible for them; and the slave of a man is a guardian of his master's property and is responsible for it. Surely, everyone of you is a guardian and responsible for his charges}}
\hadithdefcmd{bukhari}{7139}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ كَانَ مُحَمَّدُ بْنُ جُبَيْرِ بْنِ مُطْعِمٍ يُحَدِّثُ أَنَّهُ بَلَغَ مُعَاوِيَةَ وَهْوَ عِنْدَهُ فِي وَفْدٍ مِنْ قُرَيْشٍ أَنَّ عَبْدَ اللَّهِ بْنَ عَمْرٍو يُحَدِّثُ أَنَّهُ سَيَكُونُ مَلِكٌ مِنْ قَحْطَانَ فَغَضِبَ، فَقَامَ فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ، ثُمَّ قَالَ أَمَّا بَعْدُ فَإِنَّهُ بَلَغَنِي أَنَّ رِجَالاً مِنْكُمْ يُحَدِّثُونَ أَحَادِيثَ لَيْسَتْ فِي كِتَابِ اللَّهِ، وَلاَ تُؤْثَرُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأُولَئِكَ جُهَّالُكُمْ، فَإِيَّاكُمْ وَالأَمَانِيَّ الَّتِي تُضِلُّ أَهْلَهَا، فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ هَذَا الأَمْرَ فِي قُرَيْشٍ، لاَ يُعَادِيهِمْ أَحَدٌ إِلاَّ كَبَّهُ اللَّهُ عَلَى وَجْهِهِ مَا أَقَامُوا الدِّينَ ‏"‏‏.‏ تَابَعَهُ نُعَيْمٌ عَنِ ابْنِ الْمُبَارَكِ عَنْ مَعْمَرٍ عَنِ الزُّهْرِيِّ عَنْ مُحَمَّدِ بْنِ جُبَيْرٍ‏.‏\hadithno{7139}\hadithtrans{Narrated Muhammad bin Jubair bin Mut`im:That while he was included in a delegation of Quraish staying with Muawiya, Muawiya heard that `Abdullah bin `Amr had said that there would be a king from Qahtan tribe, whereupon he became very angry. He stood up, and after glorifying and praising Allah as He deserved, said, "To proceed, I have come to know that some of you men are narrating things which are neither in Allah's Book, nor has been mentioned by Allah's Messenger (ﷺ) . Such people are the ignorant among you. Beware of such vain desires that mislead those who have them. I have heard Allah's Messenger (ﷺ) saying, 'This matter (of the caliphate) will remain with the Quraish, and none will rebel against them, but Allah will throw him down on his face as long as they stick to the rules and regulations of the religion (Islam)}}
\hadithdefcmd{bukhari}{7140}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا عَاصِمُ بْنُ مُحَمَّدٍ، سَمِعْتُ أَبِي يَقُولُ، قَالَ ابْنُ عُمَرَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَزَالُ الأَمْرُ فِي قُرَيْشٍ مَا بَقِيَ مِنْهُمُ اثْنَانِ ‏"‏‏.‏\hadithno{7140}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "This matter (caliphate) will remain with the Quraish even if only two of them were still existing}}
\hadithdefcmd{bukhari}{7141}{حَدَّثَنَا شِهَابُ بْنُ عَبَّادٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ حُمَيْدٍ، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ حَسَدَ إِلاَّ فِي اثْنَتَيْنِ، رَجُلٌ آتَاهُ اللَّهُ مَالاً فَسَلَّطَهُ عَلَى هَلَكَتِهِ فِي الْحَقِّ، وَآخَرُ آتَاهُ اللَّهُ حِكْمَةً فَهْوَ يَقْضِي بِهَا وَيُعَلِّمُهَا ‏"‏‏.‏\hadithno{7141}\hadithtrans{Narrated `Abdullah:Allah's Messenger (ﷺ) said, "Do not wish to be like anyone, except in two cases: (1) A man whom Allah has given wealth and he spends it righteously. (2) A man whom Allah has given wisdom (knowledge of the Qur'an and the Hadith) and he acts according to it and teaches it to others}}
\hadithdefcmd{bukhari}{7142}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، عَنْ أَبِي التَّيَّاحِ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اسْمَعُوا وَأَطِيعُوا وَإِنِ اسْتُعْمِلَ عَلَيْكُمْ عَبْدٌ حَبَشِيٌّ كَأَنَّ رَأْسَهُ زَبِيبَةٌ ‏"‏‏.‏\hadithno{7142}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) said, "You should listen to and obey, your ruler even if he was an Ethiopian (black) slave whose head looks like a raisin}}
\hadithdefcmd{bukhari}{7143}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنِ الْجَعْدِ، عَنْ أَبِي رَجَاءٍ، عَنِ ابْنِ عَبَّاسٍ، يَرْوِيهِ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنْ رَأَى مِنْ أَمِيرِهِ شَيْئًا فَكَرِهَهُ فَلْيَصْبِرْ، فَإِنَّهُ لَيْسَ أَحَدٌ يُفَارِقُ الْجَمَاعَةَ شِبْرًا فَيَمُوتُ إِلاَّ مَاتَ مِيتَةً جَاهِلِيَّةً ‏"‏‏.‏\hadithno{7143}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "If somebody sees his Muslim ruler doing something he disapproves of, he should be patient, for whoever becomes separate from the Muslim group even for a span and then dies, he will die as those who died in the Pre-Islamic period of ignorance (as rebellious sinners). (See Hadith No. 176 and)}}
\hadithdefcmd{bukhari}{7144}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ، حَدَّثَنِي نَافِعٌ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ السَّمْعُ وَالطَّاعَةُ عَلَى الْمَرْءِ الْمُسْلِمِ، فِيمَا أَحَبَّ وَكَرِهَ، مَا لَمْ يُؤْمَرْ بِمَعْصِيَةٍ، فَإِذَا أُمِرَ بِمَعْصِيَةٍ فَلاَ سَمْعَ وَلاَ طَاعَةَ ‏"‏‏.‏\hadithno{7144}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "A Muslim has to listen to and obey (the order of his ruler) whether he likes it or not, as long as his orders involve not one in disobedience (to Allah), but if an act of disobedience (to Allah) is imposed one should not listen to it or obey it. (See Hadith No. 203, Vol)}}
\hadithdefcmd{bukhari}{7145}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا سَعْدُ بْنُ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ عَلِيٍّ ـ رضى الله عنه ـ قَالَ بَعَثَ النَّبِيُّ صلى الله عليه وسلم سَرِيَّةً، وَأَمَّرَ عَلَيْهِمْ رَجُلاً مِنَ الأَنْصَارِ وَأَمَرَهُمْ أَنْ يُطِيعُوهُ، فَغَضِبَ عَلَيْهِمْ وَقَالَ أَلَيْسَ قَدْ أَمَرَ النَّبِيُّ صلى الله عليه وسلم أَنَّ تُطِيعُونِي قَالُوا بَلَى‏.‏ قَالَ عَزَمْتُ عَلَيْكُمْ لَمَا جَمَعْتُمْ حَطَبًا وَأَوْقَدْتُمْ نَارًا، ثُمَّ دَخَلْتُمْ فِيهَا، فَجَمَعُوا حَطَبًا فَأَوْقَدُوا، فَلَمَّا هَمُّوا بِالدُّخُولِ فَقَامَ يَنْظُرُ بَعْضُهُمْ إِلَى بَعْضٍ، قَالَ بَعْضُهُمْ إِنَّمَا تَبِعْنَا النَّبِيَّ صلى الله عليه وسلم فِرَارًا مِنَ النَّارِ، أَفَنَدْخُلُهَا، فَبَيْنَمَا هُمْ كَذَلِكَ إِذْ خَمَدَتِ النَّارُ، وَسَكَنَ غَضَبُهُ، فَذُكِرَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ لَوْ دَخَلُوهَا مَا خَرَجُوا مِنْهَا أَبَدًا، إِنَّمَا الطَّاعَةُ فِي الْمَعْرُوفِ ‏"‏‏.‏\hadithno{7145}\hadithtrans{Narrated `Ali:The Prophet (ﷺ) sent an army unit (for some campaign) and appointed a man from the Ansar as its commander and ordered them (the soldiers) to obey him. (During the campaign) he became angry with them and said, "Didn't the Prophet (ﷺ) order you to obey me?" They said, "Yes." He said, "I order you to collect wood and make a fire and then throw yourselves into it." So they collected wood and made a fire, but when they were about to throw themselves into, it they started looking at each other, and some of them said, "We followed the Prophet (ﷺ) to escape from the fire. How should we enter it now?" So while they were in that state, the fire extinguished and their commander's anger abated. The event was mentioned to the Prophet (ﷺ) and he said, "If they had entered it (the fire) they would never have come out of it, for obedience is required only in what is good." (See Hadith No. 629. Vol)}}
\hadithdefcmd{bukhari}{7146}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنِ الْحَسَنِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَا عَبْدَ الرَّحْمَنِ لاَ تَسْأَلِ الإِمَارَةَ، فَإِنَّكَ إِنْ أُعْطِيتَهَا عَنْ مَسْأَلَةٍ وُكِلْتَ إِلَيْهَا، وَإِنْ أُعْطِيتَهَا عَنْ غَيْرِ مَسْأَلَةٍ أُعِنْتَ عَلَيْهَا، وَإِذَا حَلَفْتَ عَلَى يَمِينٍ فَرَأَيْتَ غَيْرَهَا خَيْرًا مِنْهَا، فَكَفِّرْ يَمِينَكَ، وَأْتِ الَّذِي هُوَ خَيْرٌ ‏"‏‏.‏\hadithno{7146}\hadithtrans{Narrated `Abdur-Rahman bin Samura:The Prophet (ﷺ) said, "O `Abdur-Rahman! Do not seek to be a ruler, for if you are given authority on your demand then you will be held responsible for it, but if you are given it without asking (for it), then you will be helped (by Allah) in it. If you ever take an oath to do something and later on you find that something else is better, then you should expiate your oath and do what is better}}
\hadithdefcmd{bukhari}{7147}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا يُونُسُ، عَنِ الْحَسَنِ، قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ سَمُرَةَ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا عَبْدَ الرَّحْمَنِ بْنَ سَمُرَةَ، لاَ تَسْأَلِ الإِمَارَةَ، فَإِنْ أُعْطِيتَهَا عَنْ مَسْأَلَةٍ وُكِلْتَ إِلَيْهَا، وَإِنْ أُعْطِيتَهَا عَنْ غَيْرِ مَسْأَلَةٍ أُعِنْتَ عَلَيْهَا، وَإِذَا حَلَفْتَ عَلَى يَمِينٍ فَرَأَيْتَ غَيْرَهَا خَيْرًا مِنْهَا، فَأْتِ الَّذِي هُوَ خَيْرٌ، وَكَفِّرْ عَنْ يَمِينِكَ ‏"‏‏.‏\hadithno{7147}\hadithtrans{Narrated `Abdur-Rahman bin Samura:Allah's Messenger (ﷺ) said, "O `Abdur-Rahman bin Samura! Do not seek to be a ruler, for if you are given authority on your demand, you will be held responsible for it, but if you are given it without asking for it, then you will be helped (by Allah) in it. If you ever take an oath to do something and later on you find that something else is better, then do what is better and make expiation for your oath}}
\hadithdefcmd{bukhari}{7148}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّكُمْ سَتَحْرِصُونَ عَلَى الإِمَارَةِ، وَسَتَكُونُ نَدَامَةً يَوْمَ الْقِيَامَةِ، فَنِعْمَ الْمُرْضِعَةُ وَبِئْسَتِ الْفَاطِمَةُ ‏"‏‏.‏ وَقَالَ مُحَمَّدُ بْنُ بَشَّارٍ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ حُمْرَانَ، حَدَّثَنَا عَبْدُ الْحَمِيدِ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ عُمَرَ بْنِ الْحَكَمِ، عَنْ أَبِي هُرَيْرَةَ، قَوْلَهُ‏.‏\hadithno{7148}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "You people will be keen to have the authority of ruling which will be a thing of regret for you on the Day of Resurrection. What an excellent wet nurse it is, yet what a bad weaning one it is}}
\hadithdefcmd{bukhari}{7149}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى ـ رضى الله عنه ـ قَالَ دَخَلْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم أَنَا وَرَجُلاَنِ مِنْ قَوْمِي فَقَالَ أَحَدُ الرَّجُلَيْنِ أَمِّرْنَا يَا رَسُولَ اللَّهِ‏.‏ وَقَالَ الآخَرُ مِثْلَهُ‏.‏ فَقَالَ ‏ "‏ إِنَّا لاَ نُوَلِّي هَذَا مَنْ سَأَلَهُ، وَلاَ مَنْ حَرَصَ عَلَيْهِ ‏"‏‏.‏\hadithno{7149}\hadithtrans{Narrated Abu Musa:Two men from my tribe and I entered upon the Prophet. One of the two men said to the Prophet, "O Allah's Messenger (ﷺ)! Appoint me as a governor," and so did the second. The Prophet (ﷺ) said, "We do not assign the authority of ruling to those who ask for it, nor to those who are keen to have it}}
\hadithdefcmd{bukhari}{7150}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا أَبُو الأَشْهَبِ، عَنِ الْحَسَنِ، أَنَّ عُبَيْدَ اللَّهِ بْنَ زِيَادٍ، عَادَ مَعْقِلَ بْنَ يَسَارٍ فِي مَرَضِهِ الَّذِي مَاتَ فِيهِ فَقَالَ لَهُ مَعْقِلٌ إِنِّي مُحَدِّثُكَ حَدِيثًا سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنْ عَبْدٍ اسْتَرْعَاهُ اللَّهُ رَعِيَّةً، فَلَمْ يَحُطْهَا بِنَصِيحَةٍ، إِلاَّ لَمْ يَجِدْ رَائِحَةَ الْجَنَّةِ ‏"‏‏.‏\hadithno{7150}\hadithtrans{Narrated Ma'qil:I heard the Prophet (ﷺ) saying, "Any man whom Allah has given the authority of ruling some people and he does not look after them in an honest manner, will never feel even the smell of Paradise}}
\hadithdefcmd{bukhari}{7151}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا حُسَيْنٌ الْجُعْفِيُّ، قَالَ زَائِدَةُ ذَكَرَهُ عَنْ هِشَامٍ، عَنِ الْحَسَنِ، قَالَ أَتَيْنَا مَعْقِلَ بْنَ يَسَارٍ نَعُودُهُ فَدَخَلَ عُبَيْدُ اللَّهِ فَقَالَ لَهُ مَعْقِلٌ أُحَدِّثُكَ حَدِيثًا سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ مَا مِنْ وَالٍ يَلِي رَعِيَّةً مِنَ الْمُسْلِمِينَ، فَيَمُوتُ وَهْوَ غَاشٌّ لَهُمْ، إِلاَّ حَرَّمَ اللَّهُ عَلَيْهِ الْجَنَّةَ ‏"‏‏.‏\hadithno{7151}\hadithtrans{Narrated Ma'qil:Allah's Messenger (ﷺ) said, "If any ruler having the authority to rule Muslim subjects dies while he is deceiving them, Allah will forbid Paradise for him}}
\hadithdefcmd{bukhari}{7152}{حَدَّثَنَا إِسْحَاقُ الْوَاسِطِيُّ، حَدَّثَنَا خَالِدٌ، عَنِ الْجُرَيْرِيِّ، عَنِ طَرِيفٍ أَبِي تَمِيمَةَ، قَالَ شَهِدْتُ صَفْوَانَ وَجُنْدَبًا وَأَصْحَابَهُ وَهْوَ يُوصِيهِمْ فَقَالُوا هَلْ سَمِعْتَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم شَيْئًا قَالَ سَمِعْتُهُ يَقُولُ ‏"‏ مَنْ سَمَّعَ سَمَّعَ اللَّهُ بِهِ يَوْمَ الْقِيَامَةِ ـ قَالَ ـ وَمَنْ يُشَاقِقْ يَشْقُقِ اللَّهُ عَلَيْهِ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏ فَقَالُوا أَوْصِنَا‏.‏ فَقَالَ‏"‏ إِنَّ أَوَّلَ مَا يُنْتِنُ مِنَ الإِنْسَانِ بَطْنُهُ، فَمَنِ اسْتَطَاعَ أَنْ لاَ يَأْكُلَ إِلاَّ طَيِّبًا فَلْيَفْعَلْ، وَمَنِ اسْتَطَاعَ أَنْ لاَ يُحَالَ بَيْنَهُ وَبَيْنَ الْجَنَّةِ بِمِلْءِ كَفِّهِ مِنْ دَمٍ أَهْرَاقَهُ فَلْيَفْعَلْ ‏"‏‏.‏ قُلْتُ لأَبِي عَبْدِ اللَّهِ مَنْ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم جُنْدَبٌ قَالَ نَعَمْ جُنْدَبٌ‏.‏\hadithno{7152}\hadithtrans{Narrated Tarif Abi Tamima:I saw Safwan and Jundab and Safwan's companions when Jundab was advising. They said, "Did you hear something from Allah's Messenger (ﷺ)?" Jundab said, "I heard him saying, 'Whoever does a good deed in order to show off, Allah will expose his intentions on the Day of Resurrection (before the people), and whoever puts the people into difficulties, Allah will put him into difficulties on the Day of Resurrection.'" The people said (to Jundab), "Advise us." He said, "The first thing of the human body to purify is the `Abdomen, so he who can eat nothing but good food (Halal and earned lawfully) should do so, and he who does as much as he can that nothing intervene between him and Paradise by not shedding even a handful of blood, (i.e. murdering) should do so}}
\hadithdefcmd{bukhari}{7153}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ ـ رضى الله عنه ـ قَالَ بَيْنَمَا أَنَا وَالنَّبِيُّ، صلى الله عليه وسلم خَارِجَانِ مِنَ الْمَسْجِدِ فَلَقِيَنَا رَجُلٌ عِنْدَ سُدَّةِ الْمَسْجِدِ فَقَالَ يَا رَسُولَ اللَّهِ مَتَى السَّاعَةُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا أَعْدَدْتَ لَهَا ‏"‏ فَكَأَنَّ الرَّجُلَ اسْتَكَانَ ثُمَّ قَالَ يَا رَسُولَ اللَّهِ مَا أَعْدَدْتُ لَهَا كَبِيرَ صِيَامٍ وَلاَ صَلاَةٍ وَلاَ صَدَقَةٍ، وَلَكِنِّي أُحِبُّ اللَّهَ وَرَسُولَهُ‏.‏ قَالَ ‏"‏ أَنْتَ مَعَ مَنْ أَحْبَبْتَ ‏"‏‏.‏\hadithno{7153}\hadithtrans{Narrated Anas bin Malik:While the Prophet (ﷺ) and I were coming out of the mosque, a man met us outside the gate. The man said, "O Allah's Messenger (ﷺ)! When will be the Hour?" The Prophet (ﷺ) asked him, "What have you prepared for it?" The man became afraid and ashamed and then said, "O Allah's Messenger (ﷺ)! I haven't prepared for it much of fasts, prayers or charitable gifts but I love Allah and His Apostle." The Prophet (ﷺ) said, "You will be with the one whom you love}}
\hadithdefcmd{bukhari}{7154}{حَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا ثَابِتٌ الْبُنَانِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ، يَقُولُ لاِمْرَأَةٍ مِنْ أَهْلِهِ تَعْرِفِينَ فُلاَنَةَ قَالَتْ نَعَمْ‏.‏ قَالَ فَإِنَّ النَّبِيَّ صلى الله عليه وسلم مَرَّ بِهَا وَهْىَ تَبْكِي عِنْدَ قَبْرٍ فَقَالَ ‏"‏ اتَّقِي اللَّهَ وَاصْبِرِي ‏"‏‏.‏ فَقَالَتْ إِلَيْكَ عَنِّي، فَإِنَّكَ خِلْوٌ مِنْ مُصِيبَتِي‏.‏ قَالَ فَجَاوَزَهَا وَمَضَى فَمَرَّ بِهَا رَجُلٌ فَقَالَ مَا قَالَ لَكِ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏ قَالَتْ مَا عَرَفْتُهُ قَالَ إِنَّهُ لَرَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ فَجَاءَتْ إِلَى بَابِهِ فَلَمْ تَجِدْ عَلَيْهِ بَوَّابًا فَقَالَتْ يَا رَسُولَ اللَّهِ وَاللَّهِ مَا عَرَفْتُكَ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ الصَّبْرَ عِنْدَ أَوَّلِ صَدْمَةٍ ‏"‏‏.‏\hadithno{7154}\hadithtrans{Narrated Thabit Al-Bunani:Anas bin Malik said to a woman of his family, "Do you know such-and-such a woman?" She replied, "Yes." He said, "The Prophet (ﷺ) passed by her while she was weeping over a grave, and he said to her, 'Be afraid of Allah and be patient.' The woman said (to the Prophet). 'Go away from me, for you do not know my calamity.'" Anas added, "The Prophet (ﷺ) left her and proceeded. A man passed by her and asked her, 'What has Allah's Messenger (ﷺ) said to you?' She replied, 'I did not recognize him.' The man said, 'He was Allah's Messenger (ﷺ)."' Anas added, "So that woman came to the gate of the Prophet (ﷺ) and she did not find a gate-keeper there, and she said, 'O Allah's Messenger (ﷺ)! By Allah. I did not recognize you!' The Prophet said, 'No doubt, patience is at the first stroke of a calamity}}
\hadithdefcmd{bukhari}{7155}{حَدَّثَنَا مُحَمَّدُ بْنُ خَالِدٍ الذُّهْلِيُّ، حَدَّثَنَا الأَنْصَارِيُّ، مُحَمَّدٌ حَدَّثَنَا أَبِي، عَنْ ثُمَامَةَ، عَنْ أَنَسٍ، أَنَّ قَيْسَ بْنَ سَعْدٍ، كَانَ يَكُونُ بَيْنَ يَدَىِ النَّبِيِّ صلى الله عليه وسلم بِمَنْزِلَةِ صَاحِبِ الشُّرَطِ مِنَ الأَمِيرِ‏.‏\hadithno{7155}\hadithtrans{Narrated Anas:Qais bin Sa`d was to the Prophet (ﷺ) like a chief police officer to an Amir (chief)}}
\hadithdefcmd{bukhari}{7156}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ قُرَّةَ، حَدَّثَنِي حُمَيْدُ بْنُ هِلاَلٍ، حَدَّثَنَا أَبُو بُرْدَةَ، عَنْ أَبِي مُوسَى، أَنَّ النَّبِيَّ صلى الله عليه وسلم بَعَثَهُ وَأَتْبَعَهُ بِمُعَاذٍ‏.‏\hadithno{7156}\hadithtrans{Narrated Abu Musa:that the Prophet (ﷺ) sent him and sent Mu`adh after him (as rulers to Yemen)}}
\hadithdefcmd{bukhari}{7157}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ الصَّبَّاحِ، حَدَّثَنَا مَحْبُوبُ بْنُ الْحَسَنِ، حَدَّثَنَا خَالِدٌ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، أَنَّ رَجُلاً، أَسْلَمَ ثُمَّ تَهَوَّدَ، فَأَتَى مُعَاذُ بْنُ جَبَلٍ وَهْوَ عِنْدَ أَبِي مُوسَى فَقَالَ مَا هَذَا قَالَ أَسْلَمَ ثُمَّ تَهَوَّدَ‏.‏ قَالَ لاَ أَجْلِسُ حَتَّى أَقْتُلَهُ، قَضَاءُ اللَّهِ وَرَسُولِهِ صلى الله عليه وسلم‏.‏\hadithno{7157}\hadithtrans{Narrated Abu Musa:A man embraced Islam and then reverted back to Judaism. Mu`adh bin Jabal came and saw the man with Abu Musa. Mu`adh asked, "What is wrong with this (man)?" Abu Musa replied, "He embraced Islam and then reverted back to Judaism." Mu`adh said, "I will not sit down unless you kill him (as it is) the verdict of Allah and His Apostle}}
\hadithdefcmd{bukhari}{7158}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ عُمَيْرٍ، سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ أَبِي بَكْرَةَ، قَالَ كَتَبَ أَبُو بَكْرَةَ إِلَى ابْنِهِ وَكَانَ بِسِجِسْتَانَ بِأَنْ لاَ تَقْضِيَ بَيْنَ اثْنَيْنِ وَأَنْتَ غَضْبَانُ، فَإِنِّي سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَقْضِيَنَّ حَكَمٌ بَيْنَ اثْنَيْنِ وَهْوَ غَضْبَانُ ‏"‏‏.‏\hadithno{7158}\hadithtrans{Narrated `Abdur Rahman bin Abi Bakra:Abu Bakra wrote to his son who was in Sijistan: 'Do not judge between two persons when you are angry, for I heard the Prophet (ﷺ) saying, "A judge should not judge between two persons while he is in an angry mood}}
\hadithdefcmd{bukhari}{7159}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ، قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ، إِنِّي وَاللَّهِ لأَتَأَخَّرُ عَنْ صَلاَةِ الْغَدَاةِ مِنْ أَجْلِ فُلاَنٍ، مِمَّا يُطِيلُ بِنَا فِيهَا‏.‏ قَالَ فَمَا رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم قَطُّ أَشَدَّ غَضَبًا فِي مَوْعِظَةٍ مِنْهُ يَوْمَئِذٍ، ثُمَّ قَالَ ‏ "‏ يَا أَيُّهَا النَّاسُ، إِنَّ مِنْكُمْ مُنَفِّرِينَ، فَأَيُّكُمْ مَا صَلَّى بِالنَّاسِ فَلْيُوجِزْ، فَإِنَّ فِيهِمُ الْكَبِيرَ وَالضَّعِيفَ وَذَا الْحَاجَةِ ‏"‏‏.‏\hadithno{7159}\hadithtrans{Narrated Abu Mas`ud Al-Ansari:A man came to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! By Allah, I fail to attend the morning congregational prayer because so-and-so (i.e., Mu`adh bin Jabal) prolongs the prayer when he leads us for it." I had never seen the Prophet (ﷺ) more furious in giving advice than he was on that day. He then said, "O people! some of you make others dislike (good deeds, i.e. prayers etc). So whoever among you leads the people in prayer, he should shorten it because among them there are the old, the weak and the busy (needy having some jobs to do). (See Hadith No. 90, Vol)}}
\hadithdefcmd{bukhari}{7160}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي يَعْقُوبَ الْكِرْمَانِيُّ، حَدَّثَنَا حَسَّانُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا يُونُسُ، قَالَ مُحَمَّدٌ أَخْبَرَنِي سَالِمٌ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، أَخْبَرَهُ أَنَّهُ، طَلَّقَ امْرَأَتَهُ وَهْىَ حَائِضٌ، فَذَكَرَ عُمَرُ لِلنَّبِيِّ صلى الله عليه وسلم، فَتَغَيَّظَ فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ ‏ "‏ لِيُرَاجِعْهَا، ثُمَّ لْيُمْسِكْهَا حَتَّى تَطْهُرَ، ثُمَّ تَحِيضَ فَتَطْهُرَ، فَإِنْ بَدَا لَهُ أَنْ يُطَلِّقَهَا فَلْيُطَلِّقْهَا ‏"‏‏.‏\hadithno{7160}\hadithtrans{Narrated `Abdullah bin `Umar:That he had divorced his wife during her menses. `Umar mentioned that to the Prophet. Allah's Apostle became angry and said, "He must take her back (his wife) and keep her with him till she becomes clean from her menses and then to wait till she gets her next period and becomes clean again from it and only then, if he wants to divorce her, he may do so}}
\hadithdefcmd{bukhari}{7161}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، حَدَّثَنِي عُرْوَةُ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ جَاءَتْ هِنْدٌ بِنْتُ عُتْبَةَ بْنِ رَبِيعَةَ فَقَالَتْ يَا رَسُولَ اللَّهِ، وَاللَّهِ مَا كَانَ عَلَى ظَهْرِ الأَرْضِ أَهْلُ خِبَاءٍ أَحَبَّ إِلَىَّ أَنْ يَذِلُّوا مِنْ أَهْلِ خِبَائِكَ، وَمَا أَصْبَحَ الْيَوْمَ عَلَى ظَهْرِ الأَرْضِ أَهْلُ خِبَاءٍ أَحَبَّ إِلَىَّ أَنْ يَعِزُّوا مِنْ أَهْلِ خِبَائِكَ‏.‏ ثُمَّ قَالَتْ إِنَّ أَبَا سُفْيَانَ رَجُلٌ مِسِّيكٌ، فَهَلْ عَلَىَّ مِنْ حَرَجٍ أَنْ أُطْعِمَ الَّذِي لَهُ عِيَالَنَا قَالَ لَهَا ‏ "‏ لاَ حَرَجَ عَلَيْكِ أَنْ تُطْعِمِيهِمْ مِنْ مَعْرُوفٍ ‏"‏‏.‏\hadithno{7161}\hadithtrans{Narrated `Aisha:Hind bint `Utba bin Rabi`a came and said. "O Allah's Messenger (ﷺ)! By Allah, there was no family on the surface of the earth, I like to see in degradation more than I did your family, but today there is no family on the surface of the earth whom I like to see honored more than yours." Hind added, "Abu Sufyan is a miser. Is it sinful of me to feed our children from his property?" The Prophet (ﷺ) said, "There is no blame on you if you feed them (thereof) in a just and reasonable manner}}
\hadithdefcmd{bukhari}{7162}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ لَمَّا أَرَادَ النَّبِيُّ صلى الله عليه وسلم أَنْ يَكْتُبَ إِلَى الرُّومِ قَالُوا إِنَّهُمْ لاَ يَقْرَءُونَ كِتَابًا إِلاَّ مَخْتُومًا‏.‏ فَاتَّخَذَ النَّبِيُّ صلى الله عليه وسلم خَاتَمًا مِنْ فِضَّةٍ، كَأَنِّي أَنْظُرُ إِلَى وَبِيصِهِ، وَنَقْشُهُ مُحَمَّدٌ رَسُولُ اللَّهِ‏.‏\hadithno{7162}\hadithtrans{Narrated Anas bin Malik:When the Prophet (ﷺ) intended to write to the Byzantines, the people said, "They do not read a letter unless it is sealed (stamped)." Therefore the Prophet (ﷺ) took a silver ring----as if I am looking at its glitter now----and its engraving was: 'Muhammad, Apostle of Allah}}
\hadithdefcmd{bukhari}{7163}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي السَّائِبُ بْنُ يَزِيدَ ابْنُ أُخْتِ، نَمِرٍ أَنَّ حُوَيْطِبَ بْنَ عَبْدِ الْعُزَّى، أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ السَّعْدِيِّ أَخْبَرَهُ أَنَّهُ، قَدِمَ عَلَى عُمَرَ فِي خِلاَفَتِهِ فَقَالَ لَهُ عُمَرُ أَلَمْ أُحَدَّثْ أَنَّكَ تَلِي مِنْ أَعْمَالِ النَّاسِ أَعْمَالاً، فَإِذَا أُعْطِيتَ الْعُمَالَةَ كَرِهْتَهَا‏.‏ فَقُلْتُ بَلَى‏.‏ فَقَالَ عُمَرُ مَا تُرِيدُ إِلَى ذَلِكَ قُلْتُ إِنَّ لِي أَفْرَاسًا وَأَعْبُدًا، وَأَنَا بِخَيْرٍ، وَأَرِيدُ أَنْ تَكُونَ عُمَالَتِي صَدَقَةً عَلَى الْمُسْلِمِينَ‏.‏ قَالَ عُمَرُ لاَ تَفْعَلْ فَإِنِّي كُنْتُ أَرَدْتُ الَّذِي أَرَدْتَ فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُعْطِينِي الْعَطَاءَ فَأَقُولُ أَعْطِهِ أَفْقَرَ إِلَيْهِ مِنِّي‏.‏ حَتَّى أَعْطَانِي مَرَّةً مَالاً فَقُلْتُ أَعْطِهِ أَفْقَرَ إِلَيْهِ مِنِّي‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ خُذْهُ فَتَمَوَّلْهُ وَتَصَدَّقْ بِهِ، فَمَا جَاءَكَ مِنْ هَذَا الْمَالِ وَأَنْتَ غَيْرُ مُشْرِفٍ وَلاَ سَائِلٍ فَخُذْهُ، وَإِلاَّ فَلاَ تُتْبِعْهُ نَفْسَكَ ‏"‏\hadithno{7163}\hadithtrans{Narrated 'Abdullah bin As-Sa'di: That when he went to 'Umar during his Caliphate. 'Umar said to him, "Haven't I been told that you do certain jobs for the people but when you are given payment you refuse to take it?" 'Abdullah added: I said, "Yes." 'Umar said, "Why do you do so?" I said, "I have horses and slaves and I am living in prosperity and I wish that my payment should be kept as a charitable gift for the Muslims." 'Umar said, "Do not do so, for I intended to do the same as you do. Allah's Messenger (ﷺ) used to give me gifts and I used to say to him, 'Give it to a more needy one than me.' Once he gave me some money and I said, 'Give it to a more needy person than me,' whereupon the Prophet (ﷺ) said, 'Take it and keep it in your possession and then give it in charity. Take what ever comes to you of this money if you are not keen to have it and not asking for it; otherwise (i.e., if it does not come to you) do not seek to have it yourself}}
\hadithdefcmd{bukhari}{7164}{وَعَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنْ عَبْدَ اللَّهِ بْنَ عُمَرَ، قَالَ سَمِعْتُ عُمَرَ، يَقُولُ كَانَ النَّبِيُّ صلى الله عليه وسلم يُعْطِينِي الْعَطَاءَ فَأَقُولُ أَعْطِهِ أَفْقَرَ إِلَيْهِ مِنِّي‏.‏ حَتَّى أَعْطَانِي مَرَّةً مَالاً فَقُلْتُ أَعْطِهِ مَنْ هُوَ أَفْقَرُ إِلَيْهِ مِنِّي‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ خُذْهُ فَتَمَوَّلْهُ وَتَصَدَّقْ بِهِ، فَمَا جَاءَكَ مِنْ هَذَا الْمَالِ وَأَنْتَ غَيْرُ مُشْرِفٍ وَلاَ سَائِلٍ فَخُذْهُ، وَمَا لاَ فَلاَ تُتْبِعْهُ نَفْسَكَ ‏"‏‏.‏\hadithno{7164}\hadithtrans{Narrated 'Abdullah bin 'Umar:I have heard 'Umar saying, "The Prophet (ﷺ) used to give me some money (grant) and I would say (to him), 'Give it to a more needy one than me.' Once he gave me some money and I said, 'Give it to a more needy one than me.' The Prophet (ﷺ) said (to me), 'Take it and keep it in your possession and then give it in charity. Take whatever comes to you of this money while you are not keen to have it and not asking for it; take it, but you should not seek to have what you are not given}}
\hadithdefcmd{bukhari}{7165}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ الزُّهْرِيُّ عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ شَهِدْتُ الْمُتَلاَعِنَيْنِ وَأَنَا ابْنُ خَمْسَ، عَشْرَةَ فُرِّقَ بَيْنَهُمَا‏.‏\hadithno{7165}\hadithtrans{Narrated Sahl bin Sa`d:I witnessed a husband and a wife who were involved in a case of Lian. Then (the judgment of) divorce was passed. I was fifteen years of age, at that time}}
\hadithdefcmd{bukhari}{7166}{حَدَّثَنَا يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي ابْنُ شِهَابٍ، عَنْ سَهْلٍ، أَخِي بَنِي سَاعِدَةَ أَنَّ رَجُلاً، مِنَ الأَنْصَارِ جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ أَرَأَيْتَ رَجُلاً وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً، أَيَقْتُلُهُ فَتَلاَعَنَا فِي الْمَسْجِدِ وَأَنَا شَاهِدٌ‏.‏\hadithno{7166}\hadithtrans{Narrated Sahl:(the brother of Bani Sa`ida) A man from the Ansar came to the Prophet (ﷺ) and said, "If a man finds another man sleeping with his wife, should he kill him?" That man and his wife then did Lian in the mosque while I was present}}
\hadithdefcmd{bukhari}{7167}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنِي اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، وَسَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أَتَى رَجُلٌ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهْوَ فِي الْمَسْجِدِ فَنَادَاهُ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي زَنَيْتُ‏.‏ فَأَعْرَضَ عَنْهُ‏.‏ فَلَمَّا شَهِدَ عَلَى نَفْسِهِ أَرْبَعًا قَالَ ‏"‏ أَبِكَ جُنُونٌ ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ ‏"‏ اذْهَبُوا بِهِ فَارْجُمُوهُ ‏"‏‏.‏\hadithno{7167}\hadithtrans{Narrated Abu Huraira:A man came to Allah's Messenger (ﷺ) while he was in the mosque, and called him, saying, "O Allah's Apostle! I have committed illegal sexual intercourse." The Prophet (ﷺ) turned his face to the other side, but when the man gave four witnesses against himself, the Prophet (ﷺ) said to him, "Are you mad?" The man said, "No." So the Prophet (ﷺ) said (to his companions), "Take him away and stone him to death}}
\hadithdefcmd{bukhari}{7168}{قَالَ ابْنُ شِهَابٍ فَأَخْبَرَنِي مَنْ، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، قَالَ كُنْتُ فِيمَنْ رَجَمَهُ بِالْمُصَلَّى‏.‏ رَوَاهُ يُونُسُ وَمَعْمَرٌ وَابْنُ جُرَيْجٍ عَنِ الزُّهْرِيِّ عَنْ أَبِي سَلَمَةَ عَنْ جَابِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الرَّجْمِ‏.‏\hadithno{7168}\hadithtrans{(continued from above) Narrated Jabir bin Abdullah:I was one of those who stoned him at the Musalla in Al-Madina (See Hadith)}}
\hadithdefcmd{bukhari}{7169}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ زَيْنَبَ ابْنَةِ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ ـ رضى الله عنها ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّمَا أَنَا بَشَرٌ، وَإِنَّكُمْ تَخْتَصِمُونَ إِلَىَّ، وَلَعَلَّ بَعْضَكُمْ أَنْ يَكُونَ أَلْحَنَ بِحُجَّتِهِ مِنْ بَعْضٍ فَأَقْضِي نَحْوَ مَا أَسْمَعُ، فَمَنْ قَضَيْتُ لَهُ بِحَقِّ أَخِيهِ شَيْئًا فَلاَ يَأْخُذْهُ، فَإِنَّمَا أَقْطَعُ لَهُ قِطْعَةً مِنَ النَّارِ ‏"‏‏.‏\hadithno{7169}\hadithtrans{Narrated Um Salama:Allah's Messenger (ﷺ) said, "I am only a human being, and you people (opponents) come to me with your cases; and it may be that one of you can present his case eloquently in a more convincing way than the other, and I give my verdict according to what I hear. So if ever I judge (by error) and give the right of a brother to his other (brother) then he (the latter) should not take it, for I am giving him only a piece of Fire." (See Hadith No. 638, Vol)}}
\hadithdefcmd{bukhari}{7170}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ يَحْيَى، عَنْ عُمَرَ بْنِ كَثِيرٍ، عَنْ أَبِي مُحَمَّدٍ، مَوْلَى أَبِي قَتَادَةَ أَنَّ أَبَا قَتَادَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ حُنَيْنٍ ‏"‏ مَنْ لَهُ بَيِّنَةٌ عَلَى قَتِيلٍ قَتَلَهُ، فَلَهُ سَلَبُهُ ‏"‏‏.‏ فَقُمْتُ لأَلْتَمِسَ بَيِّنَةً عَلَى قَتِيلٍ، فَلَمْ أَرَ أَحَدًا يَشْهَدُ لِي، فَجَلَسْتُ، ثُمَّ بَدَا لِي فَذَكَرْتُ أَمْرَهُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَجُلٌ مِنْ جُلَسَائِهِ سِلاَحُ هَذَا الْقَتِيلِ الَّذِي يَذْكُرُ عِنْدِي‏.‏ قَالَ فَأَرْضِهِ مِنْهُ‏.‏ فَقَالَ أَبُو بَكْرٍ كَلاَّ لاَ يُعْطِهِ أُصَيْبِغَ مِنْ قُرَيْشٍ وَيَدَعَ أَسَدًا مِنْ أُسْدِ اللَّهِ يُقَاتِلُ عَنِ اللَّهِ وَرَسُولِهِ‏.‏ قَالَ فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَدَّاهُ إِلَىَّ فَاشْتَرَيْتُ مِنْهُ خِرَافًا فَكَانَ أَوَّلَ مَالٍ تَأَثَّلْتُهُ‏.‏ قَالَ لِي عَبْدُ اللَّهِ عَنِ اللَّيْثِ فَقَامَ النَّبِيُّ صلى الله عليه وسلم فَأَدَّاهُ إِلَىَّ‏.‏ وَقَالَ أَهْلُ الْحِجَازِ الْحَاكِمُ لاَ يَقْضِي بِعِلْمِهِ، شَهِدَ بِذَلِكَ فِي وِلاَيَتِهِ أَوْ قَبْلَهَا‏.‏ وَلَوْ أَقَرَّ خَصْمٌ عِنْدَهُ لآخَرَ بِحَقٍّ فِي مَجْلِسِ الْقَضَاءِ، فَإِنَّهُ لاَ يَقْضِي عَلَيْهِ فِي قَوْلِ بَعْضِهِمْ، حَتَّى يَدْعُوَ بِشَاهِدَيْنِ فَيُحْضِرَهُمَا إِقْرَارَهُ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِرَاقِ مَا سَمِعَ أَوْ رَآهُ فِي مَجْلِسِ الْقَضَاءِ قَضَى بِهِ، وَمَا كَانَ فِي غَيْرِهِ لَمْ يَقْضِ إِلاَّ بِشَاهِدَيْنِ‏.‏ وَقَالَ آخَرُونَ مِنْهُمْ بَلْ يَقْضِي بِهِ، لأَنَّهُ مُؤْتَمَنٌ، وَإِنَّمَا يُرَادُ مِنَ الشَّهَادَةِ مَعْرِفَةُ الْحَقِّ، فَعِلْمُهُ أَكْثَرُ مِنَ الشَّهَادَةِ‏.‏ وَقَالَ بَعْضُهُمْ يَقْضِي بِعِلْمِهِ فِي الأَمْوَالِ، وَلاَ يَقْضِي فِي غَيْرِهَا‏.‏ وَقَالَ الْقَاسِمُ لاَ يَنْبَغِي لِلْحَاكِمِ أَنْ يُمْضِيَ قَضَاءً بِعِلْمِهِ دُونَ عِلْمِ غَيْرِهِ، مَعَ أَنَّ عِلْمَهُ أَكْثَرُ مِنْ شَهَادَةِ غَيْرِهِ، وَلَكِنَّ فِيهِ تَعَرُّضًا لِتُهَمَةِ نَفْسِهِ عِنْدَ الْمُسْلِمِينَ، وَإِيقَاعًا لَهُمْ فِي الظُّنُونِ، وَقَدْ كَرِهَ النَّبِيُّ صلى الله عليه وسلم الظَّنَّ فَقَالَ ‏"‏ إِنَّمَا هَذِهِ صَفِيَّةُ ‏"‏‏.‏\hadithno{7170}\hadithtrans{Narrated Abu Qatada:Allah's Messenger (ﷺ) said on the Day of (the battle of) Hunain, "Whoever has killed an infidel and has a proof or a witness for it, then the salb (arms and belongings of that deceased) will be for him." I stood up to seek a witness to testify that I had killed an infidel but I could not find any witness and then sat down. Then I thought that I should mention the case to Allah's Messenger (ﷺ) (and when I did so) a man from those who were sitting with him said, "The arms of the killed person he has mentioned, are with me, so please satisfy him on my behalf." Abu Bakr said, "No, he will not give the arms to a bird of Quraish and deprive one of Allah's lions of it who fights for the cause of Allah and His Apostle." Allah's Messenger (ﷺ) stood up and gave it to me, and I bought a garden with its price, and that was my first property which I owned through the war booty. The people of Hijaz said, "A judge should not pass a judgment according to his knowledge, whether he was a witness at the time he was the judge or before that" And if a litigant gives a confession in favor of his opponent in the court, in the opinion of some scholars, the judge should not pass a judgment against him till the latter calls two witnesses to witness his confession. And some people of Iraq said, "A judge can pass a judgement according to what he hears or witnesses (the litigant's confession) in the court itself, but if the confession takes place outside the court, he should not pass the judgment unless two witnesses witness the confession." Some of them said, "A judge can pass a judgement depending on his knowledge of the case as he is trust-worthy, and that a witness is Required just to reveal the truth. The judge's knowledge is more than the witness." Some said, "A judge can judge according to his knowledge only in cases involving property, but in other cases he cannot." Al-Qasim said, "A judge ought not to pass a judgment depending on his knowledge if other people do not know what he knows, although his knowledge is more than the witness of somebody else because he might expose himself to suspicion by the Muslims and cause the Muslims to have unreasonable doubt}}
\hadithdefcmd{bukhari}{7171}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ، عَنِ ابْنِ شِهَابٍ، عَنْ عَلِيِّ بْنِ حُسَيْنٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَتَتْهُ صَفِيَّةُ بِنْتُ حُيَىٍّ فَلَمَّا رَجَعَتِ انْطَلَقَ مَعَهَا، فَمَرَّ بِهِ رَجُلاَنِ مِنَ الأَنْصَارِ فَدَعَاهُمَا فَقَالَ ‏"‏ إِنَّمَا هِيَ صَفِيَّةُ ‏"‏‏.‏ قَالاَ سُبْحَانَ اللَّهِ‏.‏ قَالَ ‏"‏ إِنَّ الشَّيْطَانَ يَجْرِي مِنِ ابْنِ آدَمَ مَجْرَى الدَّمِ ‏"‏‏.‏ رَوَاهُ شُعَيْبٌ وَابْنُ مُسَافِرٍ وَابْنُ أَبِي عَتِيقٍ وَإِسْحَاقُ بْنُ يَحْيَى عَنِ الزُّهْرِيِّ عَنْ عَلِيٍّ ـ يَعْنِي ابْنَ حُسَيْنٍ ـ عَنْ صَفِيَّةَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{7171}\hadithtrans{Narrated `Ali bin Husain:Safiya bint (daughter of) Huyai came to the Prophet (in the mosque), and when she returned (home), the Prophet (ﷺ) accompanied her. It happened that two men from the Ansar passed by them and the Prophet called them saying, "She is Safiya!" those two men said, "Subhan Allah!" The Prophet (ﷺ) said, "Satan circulates in the human body as blood does}}
\hadithdefcmd{bukhari}{7172}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا الْعَقَدِيُّ، حَدَّثَنَا شُعْبَةُ، عَنْ سَعِيدِ بْنِ أَبِي بُرْدَةَ، قَالَ سَمِعْتُ أَبِي قَالَ، بَعَثَ النَّبِيُّ صلى الله عليه وسلم أَبِي وَمُعَاذَ بْنَ جَبَلٍ عَلَى الْيَمَنِ فَقَالَ ‏"‏ يَسِّرَا وَلاَ تُعَسِّرَا، وَبَشِّرَا وَلاَ تُنَفِّرَا، وَتَطَاوَعَا ‏"‏‏.‏ فَقَالَ لَهُ أَبُو مُوسَى إِنَّهُ يُصْنَعُ بِأَرْضِنَا الْبِتْعُ‏.‏ فَقَالَ ‏"‏ كُلُّ مُسْكِرٍ حَرَامٌ ‏"‏‏.‏ وَقَالَ النَّضْرُ وَأَبُو دَاوُدَ وَيَزِيدُ بْنُ هَارُونَ وَوَكِيعٌ عَنْ شُعْبَةَ عَنْ سَعِيدٍ عَنْ أَبِيهِ عَنْ جَدِّهِ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{7172}\hadithtrans{Narrated Abu Burda:The Prophet (ﷺ) sent my father and Mu`adh bin Jabal to Yemen and said (to them), "Make things easy for the people and do not put hurdles in their way, and give them glad tiding, and don't let them have aversion (i.e. to make people to hate good deeds) and you both should work in cooperation and mutual understanding" Abu Musa said to Allah's Messenger (ﷺ), "In our country a special alcoholic drink called Al- Bit', is prepared (for drinking)." The Prophet (ﷺ) said, "Every intoxicant is prohibited}}
\hadithdefcmd{bukhari}{7173}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، حَدَّثَنِي مَنْصُورٌ، عَنْ أَبِي وَائِلٍ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ فُكُّوا الْعَانِيَ وَأَجِيبُوا الدَّاعِيَ ‏"‏‏.‏\hadithno{7173}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) said, "Set free the captives and accept invitations}}
\hadithdefcmd{bukhari}{7174}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، أَنَّهُ سَمِعَ عُرْوَةَ، أَخْبَرَنَا أَبُو حُمَيْدٍ السَّاعِدِيُّ، قَالَ اسْتَعْمَلَ النَّبِيُّ صلى الله عليه وسلم رَجُلاً مِنْ بَنِي أَسَدٍ يُقَالُ لَهُ ابْنُ الأُتَبِيَّةِ عَلَى صَدَقَةٍ فَلَمَّا قَدِمَ قَالَ هَذَا لَكُمْ وَهَذَا أُهْدِيَ لِي‏.‏ فَقَامَ النَّبِيُّ صلى الله عليه وسلم عَلَى الْمِنْبَرِ ـ قَالَ سُفْيَانُ أَيْضًا فَصَعِدَ الْمِنْبَرَ ـ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏"‏ مَا بَالُ الْعَامِلِ نَبْعَثُهُ، فَيَأْتِي يَقُولُ هَذَا لَكَ وَهَذَا لِي‏.‏ فَهَلاَّ جَلَسَ فِي بَيْتِ أَبِيهِ وَأُمِّهِ فَيَنْظُرُ أَيُهْدَى لَهُ أَمْ لاَ، وَالَّذِي نَفْسِي بِيَدِهِ لاَ يَأْتِي بِشَىْءٍ إِلاَّ جَاءَ بِهِ يَوْمَ الْقِيَامَةِ يَحْمِلُهُ عَلَى رَقَبَتِهِ، إِنْ كَانَ بَعِيرًا لَهُ رُغَاءٌ، أَوْ بَقَرَةً لَهَا خُوَارٌ، أَوْ شَاةً تَيْعَرُ ‏"‏‏.‏ ثُمَّ رَفَعَ يَدَيْهِ حَتَّى رَأَيْنَا عُفْرَتَىْ إِبْطَيْهِ ‏"‏ أَلاَ هَلْ بَلَّغْتُ ‏"‏ ثَلاَثًا‏.‏ قَالَ سُفْيَانُ قَصَّهُ عَلَيْنَا الزُّهْرِيُّ‏.‏ وَزَادَ هِشَامٌ عَنْ أَبِيهِ عَنْ أَبِي حُمَيْدٍ قَالَ سَمِعَ أُذُنَاىَ وَأَبْصَرَتْهُ عَيْنِي، وَسَلُوا زَيْدَ بْنَ ثَابِتٍ فَإِنَّهُ سَمِعَهُ مَعِي‏.‏ وَلَمْ يَقُلِ الزُّهْرِيُّ سَمِعَ أُذُنِي‏.‏ ‏\{‏خُوَارٌ‏\}‏ صَوْتٌ، وَالْجُؤَارُ مِنْ تَجْأَرُونَ كَصَوْتِ الْبَقَرَةِ‏.‏\hadithno{7174}\hadithtrans{Narrated Abu Humaid Al-Sa`idi:The Prophet (ﷺ) appointed a man from the tribe of Bani Asad, called Ibn Al-Utabiyya to collect the Zakat. When he returned (with the money) he said (to the Prophet), "This is for you and this has been given to me as a gift." The Prophet (ﷺ) stood up on the pulpit (Sufyan said he ascended the pulpit), and after glorifying and praising Allah, he said, "What is wrong with the employee whom we send (to collect Zakat from the public) that he returns to say, 'This is for you and that is for me?' Why didn't he stay at his father's and mother's house to see whether he will be given gifts or not? By Him in Whose Hand my life is, whoever takes anything illegally will bring it on the Day of Resurrection by carrying it over his neck: if it is a camel, it will be grunting: if it is a cow, it will be mooing: and if it is a sheep it will be bleating!" The Prophet (ﷺ) then raised both his hands till we saw the whiteness of his armpits (and he said), "No doubt! Haven't I conveyed Allah's Message?" And he repeated it three times}}
\hadithdefcmd{bukhari}{7175}{حَدَّثَنَا عُثْمَانُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي ابْنُ جُرَيْجٍ، أَنَّ نَافِعًا، أَخْبَرَهُ أَنَّ ابْنَ عُمَرَ ـ رضى الله عنهما ـ أَخْبَرَهُ قَالَ كَانَ سَالِمٌ مَوْلَى أَبِي حُذَيْفَةَ يَؤُمُّ الْمُهَاجِرِينَ الأَوَّلِينَ وَأَصْحَابَ النَّبِيِّ صلى الله عليه وسلم فِي مَسْجِدِ قُبَاءٍ، فِيهِمْ أَبُو بَكْرٍ وَعُمَرُ وَأَبُو سَلَمَةَ وَزَيْدٌ وَعَامِرُ بْنُ رَبِيعَةَ‏.‏\hadithno{7175}\hadithtrans{Narrated Ibn `Umar:Salim, the freed salve of Abu Hudhaifa used to lead in prayer the early Muhajirin (emigrants) and the companions of the Prophet (ﷺ) in the Quba mosque. Among those (who used to pray behind him) were Abu Bakr, `Umar, Abu Salama, and Amir bin Rabi`a}}
\hadithdefcmd{bukhari}{7177}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي أُوَيْسٍ، حَدَّثَنِي إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ عَمِّهِ، مُوسَى بْنِ عُقْبَةَ قَالَ ابْنُ شِهَابٍ حَدَّثَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ مَرْوَانَ بْنَ الْحَكَمِ، وَالْمِسْوَرَ بْنَ مَخْرَمَةَ، أَخْبَرَاهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ حِينَ أَذِنَ لَهُمُ الْمُسْلِمُونَ فِي عِتْقِ سَبْىِ هَوَازِنَ ‏ "‏ إِنِّي لاَ أَدْرِي مَنْ أَذِنَ مِنْكُمْ مِمَّنْ لَمْ يَأْذَنْ، فَارْجِعُوا حَتَّى يَرْفَعَ إِلَيْنَا عُرَفَاؤُكُمْ أَمْرَكُمْ ‏"‏‏.‏ فَرَجَعَ النَّاسُ فَكَلَّمَهُمْ عُرَفَاؤُهُمْ، فَرَجَعُوا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَخْبَرُوهُ أَنَّ النَّاسَ قَدْ طَيَّبُوا وَأَذِنُوا‏.‏\hadithno{7177}\hadithtrans{Narrated `Urwa bin Az-Zubair:Marwan bin Al-Hakam and Al-Miswar bin Makhrama told him that when the Muslims were permitted to set free the captives of Hawazin, Allah's Messenger (ﷺ) said, "I do not know who amongst you has agreed (to it) and who has not. Go back so that your 'Urafa' may submit your decision to us." So the people returned and their 'Urafa' talked to them and then came back to Allah's Messenger (ﷺ) and told him that the people had given their consent happily and permitted (their captives to be freed)}}
\hadithdefcmd{bukhari}{7178}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا عَاصِمُ بْنُ مُحَمَّدِ بْنِ زَيْدِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، قَالَ أُنَاسٌ لاِبْنِ عُمَرَ إِنَّا نَدْخُلُ عَلَى سُلْطَانِنَا فَنَقُولُ لَهُمْ خِلاَفَ مَا نَتَكَلَّمُ إِذَا خَرَجْنَا مِنْ عِنْدِهِمْ قَالَ كُنَّا نَعُدُّهَا نِفَاقًا‏.‏\hadithno{7178}\hadithtrans{Narrated Muhammad bin Zaid bin `Abdullah bin `Umar:Some people said to Ibn `Umar, "When we enter upon our ruler(s) we say in their praise what is contrary to what we say when we leave them." Ibn `Umar said, "We used to consider this as hypocrisy}}
\hadithdefcmd{bukhari}{7179}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عِرَاكٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنْ شَرَّ النَّاسِ ذُو الْوَجْهَيْنِ، الَّذِي يَأْتِي هَؤُلاَءِ بِوَجْهٍ وَهَؤُلاَءِ بِوَجْهٍ ‏"‏‏.‏\hadithno{7179}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The worst of all mankind is the double-faced one, who comes to some people with one face and to others, with another face}}
\hadithdefcmd{bukhari}{7180}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ هِنْدَ، قَالَتْ لِلنَّبِيِّ صلى الله عليه وسلم إِنَّ أَبَا سُفْيَانَ رَجُلٌ شَحِيحٌ، فَأَحْتَاجُ أَنْ آخُذَ مِنْ مَالِهِ‏.‏ قَالَ ‏ "‏ خُذِي مَا يَكْفِيكِ وَوَلَدَكِ بِالْمَعْرُوفِ ‏"‏‏.‏\hadithno{7180}\hadithtrans{Narrated `Aisha:Hind (bint `Utba) said to the Prophet (ﷺ) "Abu Sufyan is a miserly man and I need to take some money of his wealth." The Prophet (ﷺ) said, "Take reasonably what is sufficient for you and your children}}
\hadithdefcmd{bukhari}{7181}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ زَيْنَبَ ابْنَةَ أَبِي سَلَمَةَ، أَخْبَرَتْهُ أَنَّ أُمَّ سَلَمَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهَا عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ سَمِعَ خُصُومَةً بِبَابِ حُجْرَتِهِ فَخَرَجَ إِلَيْهِمْ فَقَالَ ‏ "‏ إِنَّمَا أَنَا بَشَرٌ، وَإِنَّهُ يَأْتِينِي الْخَصْمُ، فَلَعَلَّ بَعْضَكُمْ أَنْ يَكُونَ أَبْلَغَ مِنْ بَعْضٍ، فَأَحْسِبُ أَنَّهُ صَادِقٌ فَأَقْضِي لَهُ بِذَلِكَ، فَمَنْ قَضَيْتُ لَهُ بِحَقِّ مُسْلِمٍ، فَإِنَّمَا هِيَ قِطْعَةٌ مِنَ النَّارِ، فَلْيَأْخُذْهَا أَوْ لِيَتْرُكْهَا ‏"‏‏.‏\hadithno{7181}\hadithtrans{Narrated Um Salama:(the wife of the Prophet) Allah's Messenger (ﷺ) heard some people quarreling at the door of his dwelling, so he went out to them and said, "I am only a human being, and litigants with cases of dispute come to me, and someone of you may happen to be more eloquent (in presenting his case) than the other, whereby I may consider that he is truthful and pass a judgment in his favor. If ever I pass a judgment in favor of somebody whereby he takes a Muslim's right unjustly, then whatever he takes is nothing but a piece of Fire, and it is up to him to take or leave}}
\hadithdefcmd{bukhari}{7182}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ كَانَ عُتْبَةُ بْنُ أَبِي وَقَّاصٍ عَهِدَ إِلَى أَخِيهِ سَعْدِ بْنِ أَبِي وَقَّاصٍ أَنَّ ابْنَ وَلِيدَةِ زَمْعَةَ مِنِّي فَاقْبِضْهُ إِلَيْكَ‏.‏ فَلَمَّا كَانَ عَامُ الْفَتْحِ أَخَذَهُ سَعْدٌ فَقَالَ ابْنُ أَخِي، قَدْ كَانَ عَهِدَ إِلَىَّ فِيهِ، فَقَامَ إِلَيْهِ عَبْدُ بْنُ زَمْعَةَ فَقَالَ أَخِي وَابْنُ وَلِيدَةِ أَبِي، وُلِدَ عَلَى فِرَاشِهِ‏.‏ فَتَسَاوَقَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ سَعْدٌ يَا رَسُولَ اللَّهِ ابْنُ أَخِي، كَانَ عَهِدَ إِلَىَّ فِيهِ‏.‏ وَقَالَ عَبْدُ بْنُ زَمْعَةَ أَخِي وَابْنُ وَلِيدَةِ أَبِي، وُلِدَ عَلَى فِرَاشِهِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هُوَ لَكَ يَا عَبْدُ بْنَ زَمْعَةَ ‏"‏‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْوَلَدُ لِلْفِرَاشِ، وَلِلْعَاهِرِ الْحَجَرُ ‏"‏‏.‏ ثُمَّ قَالَ لِسَوْدَةَ بِنْتِ زَمْعَةَ ‏"‏ احْتَجِبِي مِنْهُ ‏"‏، لِمَا رَأَى مِنْ شَبَهِهِ بِعُتْبَةَ، فَمَا رَآهَا حَتَّى لَقِيَ اللَّهَ تَعَالَى‏.‏\hadithno{7182}\hadithtrans{Narrated `Aisha:(the wife of the Prophet) `Utba bin Abi Waqqas said to his brother Sa`d bin Abi Waqqas, "The son of the slave girl of Zam`a is from me, so take him into your custody." So in the year of Conquest of Mecca, Sa`d took him and said. (This is) my brother's son whom my brother has asked me to take into my custody." `Abd bin Zam`a got up before him and said, (He is) my brother and the son of the slave girl of my father, and was born on my father's bed." So they both submitted their case before Allah's Apostle. Sa`d said, "O Allah's Messenger (ﷺ)! This boy is the son of my brother and he entrusted him to me." `Abd bin Zam`a said, "This boy is my brother and the son of the slave girl of my father, and was born on the bed of my father." Allah's Messenger (ﷺ) said, "The boy is for you, O `Abd bin Zam`a!" Then Allah's Apostle further said, "The child is for the owner of the bed, and the stone is for the adulterer," He then said to Sauda bint Zam`a, "Veil (screen) yourself before him," when he saw the child's resemblance to `Utba. The boy did not see her again till he met Allah}}
\hadithdefcmd{bukhari}{7184}{حَدَّثَنَا إِسْحَاقُ بْنُ نَصْرٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، وَالأَعْمَشِ، عَنْ أَبِي وَائِلٍ، قَالَ قَالَ عَبْدُ اللَّهِ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ يَحْلِفُ عَلَى يَمِينِ صَبْرٍ، يَقْتَطِعُ مَالاً وَهْوَ فِيهَا فَاجِرٌ، إِلاَّ لَقِيَ اللَّهَ وَهْوَ عَلَيْهِ غَضْبَانُ ‏"‏‏.‏ فَأَنْزَلَ اللَّهُ ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ‏\}‏ الآيَةَ‏.‏ فَجَاءَ الأَشْعَثُ وَعَبْدُ اللَّهِ يُحَدِّثُهُمْ فَقَالَ فِيَّ نَزَلَتْ وَفِي رَجُلٍ خَاصَمْتُهُ فِي بِئْرٍ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَلَكَ بَيِّنَةٌ ‏"‏‏.‏ قُلْتُ لاَ‏.‏ قَالَ ‏"‏ فَلْيَحْلِفْ ‏"‏‏.‏ قُلْتُ إِذًا يَحْلِفُ‏.‏ فَنَزَلَتْ ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ‏\}‏ الآيَةَ‏.‏\hadithno{7184}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "If somebody on the demand of a judge takes an oath to grab (a Muslim's) property and he is liar in it, he will meet Allah Who will be angry with him". So Allah revealed,:-- 'Verily! those who purchase a small gain at the cost of Allah's Covenant and their oaths..' (3.77) 'Al- Ashath came while `Abdullah was narrating (this) to the people. Al-Ashath said, "This verse was revealed regarding me and another man with whom I had a quarrel about a well. The Prophet (ﷺ) said (to me), "Do you have any evidence?' I replied, 'No.' He said, 'Let your opponent take an oath.' I said: I am sure he would take a (false) oath." Thereupon it was revealed: 'Verily! those who purchase a small gain at the cost of Allah's Covenant....' (3.77) (See Hadith No. 72, Vol)}}
\hadithdefcmd{bukhari}{7185}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ زَيْنَبَ بِنْتَ أَبِي سَلَمَةَ، أَخْبَرَتْهُ عَنْ أُمِّهَا أُمِّ سَلَمَةَ، قَالَتْ سَمِعَ النَّبِيُّ صلى الله عليه وسلم جَلَبَةَ خِصَامٍ عِنْدَ بَابِهِ فَخَرَجَ عَلَيْهِمْ فَقَالَ ‏ "‏ إِنَّمَا أَنَا بَشَرٌ، وَإِنَّهُ يَأْتِينِي الْخَصْمُ، فَلَعَلَّ بَعْضًا أَنْ يَكُونَ أَبْلَغَ مِنْ بَعْضٍ، أَقْضِي لَهُ بِذَلِكَ وَأَحْسِبُ أَنَّهُ صَادِقٌ، فَمَنْ قَضَيْتُ لَهُ بِحَقِّ مُسْلِمٍ فَإِنَّمَا هِيَ قِطْعَةٌ مِنَ النَّارِ، فَلْيَأْخُذْهَا أَوْ لِيَدَعْهَا ‏"‏‏.‏\hadithno{7185}\hadithtrans{Narrated Um Salama:The Prophet (ﷺ) heard the voices of some people quarreling near his gate, so he went to them and said, "I am only a human being and litigants with cases of disputes come to me, and maybe one of them presents his case eloquently in a more convincing and impressive way than the other, and I give my verdict in his favor thinking he is truthful. So if I give a Muslim's right to another (by mistake), then that (property) is a piece of Fire, which is up to him to take it or leave it." (See Hadith No)}}
\hadithdefcmd{bukhari}{7186}{حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنَا سَلَمَةُ بْنُ كُهَيْلٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، قَالَ بَلَغَ النَّبِيَّ صلى الله عليه وسلم أَنَّ رَجُلاً مِنْ أَصْحَابِهِ أَعْتَقَ غُلاَمًا عَنْ دُبُرٍ، لَمْ يَكُنْ لَهُ مَالٌ غَيْرَهُ، فَبَاعَهُ بِثَمَانِمِائَةِ دِرْهَمٍ، ثُمَّ أَرْسَلَ بِثَمَنِهِ إِلَيْهِ‏.‏\hadithno{7186}\hadithtrans{Narrated Jabir:The Prophet (ﷺ) came to know that one of his companions had given the promise of freeing his slave after his death, but as he had no other property than that slave, the Prophet (ﷺ) sold that slave for 800 dirhams and sent the price to him}}
\hadithdefcmd{bukhari}{7187}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُسْلِمٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دِينَارٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ ـ رضى الله عنهما ـ يَقُولُ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَعْثًا وَأَمَّرَ عَلَيْهِمْ أُسَامَةَ بْنَ زَيْدٍ، فَطُعِنَ فِي إِمَارَتِهِ، وَقَالَ ‏ "‏ إِنْ تَطْعَنُوا فِي إِمَارَتِهِ فَقَدْ كُنْتُمْ تَطْعَنُونَ فِي إِمَارَةِ أَبِيهِ مِنْ قَبْلِهِ، وَايْمُ اللَّهِ إِنْ كَانَ لَخَلِيقًا لِلإِمْرَةِ، وَإِنْ كَانَ لَمِنْ أَحَبِّ النَّاسِ إِلَىَّ، وَإِنَّ هَذَا لَمِنْ أَحَبِّ النَّاسِ إِلَىَّ بَعْدَهُ ‏"‏‏.‏\hadithno{7187}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) sent an army unit headed by Usama bin Zaid and the people criticized his leadership. The Prophet (ﷺ) said (to the people), "If you are criticizing his leadership now, then you used to criticize his father's leadership before. By Allah, he (Usama's father) deserved the leadership and used to be one of the most beloved persons to me, and now his son (Usama) is one of the most beloved persons to me after him. " (See Hadith No. 745, Vol)}}
\hadithdefcmd{bukhari}{7188}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، سَمِعْتُ ابْنَ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَبْغَضُ الرِّجَالِ إِلَى اللَّهِ الأَلَدُّ الْخَصِمُ ‏"‏‏.‏\hadithno{7188}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) said, "The most hated person in the sight of Allah, is the most quarrelsome person}}
\hadithdefcmd{bukhari}{7189}{حَدَّثَنَا مَحْمُودٌ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، بَعَثَ النَّبِيُّ صلى الله عليه وسلم خَالِدًا ح وَحَدَّثَنِي نُعَيْمٌ أَخْبَرَنَا عَبْدُ اللَّهِ أَخْبَرَنَا مَعْمَرٌ عَنِ الزُّهْرِيِّ عَنْ سَالِمٍ عَنْ أَبِيهِ قَالَ بَعَثَ النَّبِيُّ صلى الله عليه وسلم خَالِدَ بْنَ الْوَلِيدِ إِلَى بَنِي جَذِيمَةَ فَلَمْ يُحْسِنُوا أَنْ يَقُولُوا أَسْلَمْنَا‏.‏ فَقَالُوا صَبَأْنَا صَبَأْنَا، فَجَعَلَ خَالِدٌ يَقْتُلُ وَيَأْسِرُ، وَدَفَعَ إِلَى كُلِّ رَجُلٌ مِنَّا أَسِيرَهُ، فَأَمَرَ كُلَّ رَجُلٍ مِنَّا أَنْ يَقْتُلَ أَسِيرَهُ، فَقُلْتُ وَاللَّهِ لاَ أَقْتُلُ أَسِيرِي وَلاَ يَقْتُلُ رَجُلٌ مِنْ أَصْحَابِي أَسِيرَهُ‏.‏ فَذَكَرْنَا ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ اللَّهُمَّ إِنِّي أَبْرَأُ إِلَيْكَ مِمَّا صَنَعَ خَالِدُ بْنُ الْوَلِيدِ ‏"‏، مَرَّتَيْنِ‏.‏\hadithno{7189}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) sent (an army unit under the command of) Khalid bin Al-Walid to fight against the tribe of Bani Jadhima and those people could not express themselves by saying, "Aslamna," but they said, "Saba'na! Saba'na! " Khalid kept on killing some of them and taking some others as captives, and he gave a captive to everyone of us and ordered everyone of us to kill his captive. I said, "By Allah, I shall not kill my captive and none of my companions shall kill his captive!" Then we mentioned that to the Prophet (ﷺ) and he said, "O Allah! I am free from what Khalid bin Al-Walid has done," and repeated it twice}}
\hadithdefcmd{bukhari}{7190}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا أَبُو حَازِمٍ الْمَدِينِيُّ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، قَالَ كَانَ قِتَالٌ بَيْنَ بَنِي عَمْرٍو، فَبَلَغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم فَصَلَّى الظُّهْرَ، ثُمَّ أَتَاهُمْ يُصْلِحُ بَيْنَهُمْ، فَلَمَّا حَضَرَتْ صَلاَةُ الْعَصْرِ فَأَذَّنَ بِلاَلٌ وَأَقَامَ وَأَمَرَ أَبَا بَكْرٍ فَتَقَدَّمَ، وَجَاءَ النَّبِيُّ صلى الله عليه وسلم وَأَبُو بَكْرٍ فِي الصَّلاَةِ، فَشَقَّ النَّاسَ حَتَّى قَامَ خَلْفَ أَبِي بَكْرٍ، فَتَقَدَّمَ فِي الصَّفِّ الَّذِي يَلِيهِ‏.‏ قَالَ وَصَفَّحَ الْقَوْمُ، وَكَانَ أَبُو بَكْرٍ إِذَا دَخَلَ فِي الصَّلاَةِ لَمْ يَلْتَفِتْ حَتَّى يَفْرُغَ، فَلَمَّا رَأَى التَّصْفِيحَ لاَ يُمْسَكُ عَلَيْهِ الْتَفَتَ فَرَأَى النَّبِيَّ صلى الله عليه وسلم خَلْفَهُ، فَأَوْمَأَ إِلَيْهِ النَّبِيُّ صلى الله عليه وسلم أَنِ امْضِهْ وَأَوْمَأَ بِيَدِهِ هَكَذَا، وَلَبِثَ أَبُو بَكْرٍ هُنَيَّةً يَحْمَدُ اللَّهَ عَلَى قَوْلِ النَّبِيِّ صلى الله عليه وسلم ثُمَّ مَشَى الْقَهْقَرَى، فَلَمَّا رَأَى النَّبِيُّ صلى الله عليه وسلم ذَلِكَ تَقَدَّمَ فَصَلَّى النَّبِيُّ صلى الله عليه وسلم بِالنَّاسِ، فَلَمَّا قَضَى صَلاَتَهُ قَالَ ‏"‏ يَا أَبَا بَكْرٍ مَا مَنَعَكَ إِذْ أَوْمَأْتُ إِلَيْكَ أَنْ لاَ تَكُونَ مَضَيْتَ ‏"‏‏.‏ قَالَ لَمْ يَكُنْ لاِبْنِ أَبِي قُحَافَةَ أَنْ يَؤُمَّ النَّبِيَّ صلى الله عليه وسلم‏.‏ وَقَالَ لِلْقَوْمِ ‏"‏ إِذَا نَابَكُمْ أَمْرٌ، فَلْيُسَبِّحِ الرِّجَالُ، وَلْيُصَفِّحِ النِّسَاءُ ‏"‏‏.‏\hadithno{7190}\hadithtrans{Narrated Sahl bin Sa`d As-Saidi:There was some quarrel (sighting) among Bani `Amr, and when this news reached the Prophet, he offered the Zuhr prayer and went to establish peace among them. In the meantime the time of `Asr prayer was due, Bilal pronounced the Adhan and then the Iqama for the prayer and requested Abu Bakr (to lead the prayer) and Abu Bakr went forward. The Prophet (ﷺ) arrived while Abu Bakr was still praying. He entered the rows of praying people till he stood behind Abu Bakr in the (first) row. The people started clapping, and it was the habit of Abu Bakr that whenever he stood for prayer, he never glanced side-ways till he had finished it, but when Abu Bakr observed that the clapping was not coming to an end, he looked and saw the Prophet (ﷺ) standing behind him. The Prophet (ﷺ) beckoned him to carry on by waving his hand. Abu Bakr stood there for a while, thanking Allah for the saying of the Prophet (ﷺ) and then he retreated, taking his steps backwards. When the Prophet saw that, he went ahead and led the people in prayer. When he finished the prayer, he said, "O Abu Bakr! What prevented you from carrying on with the prayer after I beckoned you to do so?" Abu Bakr replied, "It does not befit the son of Abi Quhafa to lead the Prophet (ﷺ) in prayer." Then the Prophet (ﷺ) said to the people, "If some problem arises during prayers, then the men should say, Subhan Allah!; and the women should clap." (See Hadith No. 652, Vol)}}
\hadithdefcmd{bukhari}{7191}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدِ اللَّهِ أَبُو ثَابِتٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ بْنِ السَّبَّاقِ، عَنْ زَيْدِ بْنِ ثَابِتٍ، قَالَ بَعَثَ إِلَىَّ أَبُو بَكْرٍ لِمَقْتَلِ أَهْلِ الْيَمَامَةِ وَعِنْدَهُ عُمَرُ فَقَالَ أَبُو بَكْرٍ إِنَّ عُمَرَ أَتَانِي فَقَالَ إِنَّ الْقَتْلَ قَدِ اسْتَحَرَّ يَوْمَ الْيَمَامَةِ بِقُرَّاءِ الْقُرْآنِ، وَإِنِّي أَخْشَى أَنْ يَسْتَحِرَّ الْقَتْلُ بِقُرَّاءِ الْقُرْآنِ فِي الْمَوَاطِنِ كُلِّهَا، فَيَذْهَبَ قُرْآنٌ كَثِيرٌ، وَإِنِّي أَرَى أَنْ تَأْمُرَ بِجَمْعِ الْقُرْآنِ‏.‏ قُلْتُ كَيْفَ أَفْعَلُ شَيْئًا لَمْ يَفْعَلْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ عُمَرُ هُوَ وَاللَّهِ خَيْرٌ‏.‏ فَلَمْ يَزَلْ عُمَرُ يُرَاجِعُنِي فِي ذَلِكَ حَتَّى شَرَحَ اللَّهُ صَدْرِي لِلَّذِي شَرَحَ لَهُ صَدْرَ عُمَرَ، وَرَأَيْتُ فِي ذَلِكَ الَّذِي رَأَى عُمَرُ‏.‏ قَالَ زَيْدٌ قَالَ أَبُو بَكْرٍ وَإِنَّكَ رَجُلٌ شَابٌّ عَاقِلٌ لاَ نَتَّهِمُكَ، قَدْ كُنْتَ تَكْتُبُ الْوَحْىَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَتَتَبَّعِ الْقُرْآنَ فَاجْمَعْهُ‏.‏ قَالَ زَيْدٌ فَوَاللَّهِ لَوْ كَلَّفَنِي نَقْلَ جَبَلٍ مِنَ الْجِبَالِ مَا كَانَ بِأَثْقَلَ عَلَىَّ مِمَّا كَلَّفَنِي مِنْ جَمْعِ الْقُرْآنِ‏.‏ قُلْتُ كَيْفَ تَفْعَلاَنِ شَيْئًا لَمْ يَفْعَلْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ أَبُو بَكْرٍ هُوَ وَاللَّهِ خَيْرٌ‏.‏ فَلَمْ يَزَلْ يَحُثُّ مُرَاجَعَتِي حَتَّى شَرَحَ اللَّهُ صَدْرِي لِلَّذِي شَرَحَ اللَّهُ لَهُ صَدْرَ أَبِي بَكْرٍ وَعُمَرَ، وَرَأَيْتُ فِي ذَلِكَ الَّذِي رَأَيَا، فَتَتَبَّعْتُ الْقُرْآنَ أَجْمَعُهُ مِنَ الْعُسُبِ وَالرِّقَاعِ وَاللِّخَافِ وَصُدُورِ الرِّجَالِ، فَوَجَدْتُ آخِرَ سُورَةِ التَّوْبَةِ ‏\{‏لَقَدْ جَاءَكُمْ رَسُولٌ مِنْ أَنْفُسِكُمْ‏\}‏ إِلَى آخِرِهَا مَعَ خُزَيْمَةَ أَوْ أَبِي خُزَيْمَةَ فَأَلْحَقْتُهَا فِي سُورَتِهَا، وَكَانَتِ الصُّحُفُ عِنْدَ أَبِي بَكْرٍ حَيَاتَهُ حَتَّى تَوَفَّاهُ اللَّهُ عَزَّ وَجَلَّ، ثُمَّ عِنْدَ عُمَرَ حَيَاتَهُ حَتَّى تَوَفَّاهُ اللَّهُ، ثُمَّ عِنْدَ حَفْصَةَ بِنْتِ عُمَرَ‏.‏ قَالَ مُحَمَّدُ بْنُ عُبَيْدِ اللَّهِ اللِّخَافُ يَعْنِي الْخَزَفَ‏.‏\hadithno{7191}\hadithtrans{Narrated Zaid bin Thabit:Abu Bakr sent for me owing to the large number of casualties in the battle of Al-Yamama, while `Umar was sitting with him. Abu Bakr said (to me), `Umar has come to my and said, 'A great number of Qaris of the Holy Qur'an were killed on the day of the battle of Al-Yamama, and I am afraid that the casualties among the Qaris of the Qur'an may increase on other battle-fields whereby a large part of the Qur'an may be lost. Therefore I consider it advisable that you (Abu Bakr) should have the Qur'an collected.' I said, 'How dare I do something which Allah's Messenger (ﷺ) did not do?' `Umar said, By Allah, it is something beneficial.' `Umar kept on pressing me for that till Allah opened my chest for that for which He had opened the chest of `Umar and I had in that matter, the same opinion as `Umar had." Abu Bakr then said to me (Zaid), "You are a wise young man and we do not have any suspicion about you, and you used to write the Divine Inspiration for Allah's Messenger (ﷺ). So you should search for the fragmentary scripts of the Qur'an and collect it (in one Book)." Zaid further said: By Allah, if Abu Bakr had ordered me to shift a mountain among the mountains from one place to another it would not have been heavier for me than this ordering me to collect the Qur'an. Then I said (to `Umar and Abu Bakr), "How can you do something which Allah's Messenger (ﷺ) did not do?" Abu Bakr said, "By Allah, it is something beneficial." Zaid added: So he (Abu Bakr) kept on pressing me for that until Allah opened my chest for that for which He had opened the chests of Abu Bakr and `Umar, and I had in that matter, the same opinion as theirs. So I started compiling the Qur'an by collecting it from the leafless stalks of the date-palm tree and from the pieces of leather and hides and from the stones, and from the chests of men (who had memorized the Qur'an). I found the last verses of Surat-at-Tauba: ("Verily there has come unto you an Apostle (Muhammad) from amongst yourselves--' (9.128-129) ) from Khuza`ima or Abi Khuza`ima and I added to it the rest of the Sura. The manuscripts of the Qur'an remained with Abu Bakr till Allah took him unto Him. Then it remained with `Umar till Allah took him unto Him, and then with Hafsa bint `Umar}}
\hadithdefcmd{bukhari}{7192}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي لَيْلَى، ح حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكٌ، عَنْ أَبِي لَيْلَى بْنِ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ سَهْلٍ، عَنْ سَهْلِ بْنِ أَبِي حَثْمَةَ، أَنَّهُ أَخْبَرَهُ هُوَ، وَرِجَالٌ، مِنْ كُبَرَاءِ قَوْمِهِ أَنَّ عَبْدَ اللَّهِ بْنَ سَهْلٍ وَمُحَيِّصَةَ خَرَجَا إِلَى خَيْبَرَ مِنْ جَهْدٍ أَصَابَهُمْ، فَأُخْبِرَ مُحَيِّصَةُ أَنَّ عَبْدَ اللَّهِ قُتِلَ وَطُرِحَ فِي فَقِيرٍ أَوْ عَيْنٍ، فَأَتَى يَهُودَ فَقَالَ أَنْتُمْ وَاللَّهِ قَتَلْتُمُوهُ‏.‏ قَالُوا مَا قَتَلْنَاهُ وَاللَّهِ‏.‏ ثُمَّ أَقْبَلَ حَتَّى قَدِمَ عَلَى قَوْمِهِ فَذَكَرَ لَهُمْ، وَأَقْبَلَ هُوَ وَأَخُوهُ حُوَيِّصَةُ ـ وَهْوَ أَكْبَرُ مِنْهُ ـ وَعَبْدُ الرَّحْمَنِ بْنُ سَهْلٍ، فَذَهَبَ لِيَتَكَلَّمَ وَهْوَ الَّذِي كَانَ بِخَيْبَرَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم لِمُحَيِّصَةَ ‏"‏ كَبِّرْ كَبِّرْ ‏"‏‏.‏ يُرِيدُ السِّنَّ، فَتَكَلَّمَ حُوَيِّصَةُ ثُمَّ تَكَلَّمَ مُحَيِّصَةُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِمَّا أَنْ يَدُوا صَاحِبَكُمْ، وَإِمَّا أَنْ يُؤْذِنُوا بِحَرْبٍ ‏"‏‏.‏ فَكَتَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَيْهِمْ بِهِ، فَكُتِبَ مَا قَتَلْنَاهُ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِحُوَيِّصَةَ وَمُحَيِّصَةَ وَعَبْدِ الرَّحْمَنِ ‏"‏ أَتَحْلِفُونَ وَتَسْتَحِقُّونَ دَمَ صَاحِبِكُمْ ‏"‏‏.‏ قَالُوا لاَ‏.‏ قَالَ ‏"‏ أَفَتَحْلِفُ لَكُمْ يَهُودُ ‏"‏‏.‏ قَالُوا لَيْسُوا بِمُسْلِمِينَ‏.‏ فَوَدَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ عِنْدِهِ مِائَةَ نَاقَةٍ حَتَّى أُدْخِلَتِ الدَّارَ‏.‏ قَالَ سَهْلٌ فَرَكَضَتْنِي مِنْهَا نَاقَةٌ‏.‏\hadithno{7192}\hadithtrans{Narrated Abu Laila bin `Abdullah bin `Abdur-Rahman bin Sahl:Sahl bin Abi Hathma and some great men of his tribe said, `Abdullah bin 'Sahl and Muhaiyisa went out to Khaibar as they were struck with poverty and difficult living conditions. Then Muhaiyisa was informed that `Abdullah had been killed and thrown in a pit or a spring. Muhaiyisa went to the Jews and said, "By Allah, you have killed my companion." The Jews said, "By Allah, we have not killed him." Muhaiyisa then came back to his people and told them the story. He, his elder brother Huwaiyisa and `Abdur-Rahman bin Sahl came (to the Prophet) and he who had been at Khaibar, proceeded to speak, but the Prophet (ﷺ) said to Muhaiyisa, "The eldest! The eldest!" meaning, "Let the eldest of you speak." So Huwaiyisa spoke first and then Muhaiyisa. Allah's Messenger (ﷺ) said, "The Jews should either pay the blood money of your (deceased) companion or be ready for war." After that Allah's Messenger (ﷺ) wrote a letter to the Jews in that respect, and they wrote that they had not killed him. Then Allah's Messenger (ﷺ) said to Huwaiyisa, Muhaiyisa and `Abdur-Rahman, "Can you take an oath by which you will be entitled to take the blood money?" They said, "No." He said (to them), "Shall we ask the Jews to take an oath before you?" They replied, "But the Jews are not Muslims." So Allah's Apostle gave them one-hundred she-camels as blood money from himself. Sahl added: When those she-camels were made to enter the house, one of them kicked me with its leg}}
\hadithdefcmd{bukhari}{7194}{حَدَّثَنَا آدَمُ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، قَالاَ جَاءَ أَعْرَابِيٌّ فَقَالَ يَا رَسُولَ اللَّهِ اقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ فَقَامَ خَصْمُهُ فَقَالَ صَدَقَ فَاقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ‏.‏ فَقَالَ الأَعْرَابِيُّ إِنَّ ابْنِي كَانَ عَسِيفًا عَلَى هَذَا فَزَنَى بِامْرَأَتِهِ، فَقَالُوا لِي عَلَى ابْنِكَ الرَّجْمُ‏.‏ فَفَدَيْتُ ابْنِي مِنْهُ بِمِائَةٍ مِنَ الْغَنَمِ وَوَلِيدَةٍ، ثُمَّ سَأَلْتُ أَهْلَ الْعِلْمِ فَقَالُوا إِنَّمَا عَلَى ابْنِكَ جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لأَقْضِيَنَّ بَيْنَكُمَا بِكِتَابِ اللَّهِ، أَمَّا الْوَلِيدَةُ وَالْغَنَمُ فَرَدٌّ عَلَيْكَ، وَعَلَى ابْنِكَ جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ، وَأَمَّا أَنْتَ يَا أُنَيْسُ ـ لِرَجُلٍ ـ فَاغْدُ عَلَى امْرَأَةِ هَذَا فَارْجُمْهَا ‏"‏‏.‏ فَغَدَا عَلَيْهَا أُنَيْسٌ فَرَجَمَهَا‏.‏\hadithno{7194}\hadithtrans{Narrated Abu Huraira and Zaid bin Khalid Al-Juhani:A bedouin came and said, "O Allah's Messenger (ﷺ)! Judge between us according to Allah's Book (Laws)." His opponent stood up and said, "He has said the truth, so judge between us according to Allah's Laws." The bedouin said, "My son was a laborer for this man and committed illegal sexual intercourse with his wife. The people said to me, 'Your son is to be stoned to death,' so I ransomed my son for one hundred sheep and a slave girl. Then I asked the religious learned men and they said to me, 'Your son has to receive one hundred lashes plus one year of exile.' " The Prophet (ﷺ) said, "I shall judge between you according to Allah's Book (Laws)! As for the slave girl and the sheep, it shall be returned to you, and your son shall receive one-hundred lashes and be exiled for one year. O you, Unais!" The Prophet (ﷺ) addressed some man, "Go in the morning to the wife of this man and stone her to death." So Unais went to her the next morning and stoned her to death}}
\hadithdefcmd{bukhari}{7195}{وَقَالَ خَارِجَةُ بْنُ زَيْدِ بْنِ ثَابِتٍ عَنْ زَيْدِ بْنِ ثَابِتٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَهُ أَنْ يَتَعَلَّمَ كِتَابَ الْيَهُودِ، حَتَّى كَتَبْتُ لِلنَّبِيِّ صلى الله عليه وسلم كُتُبَهُ، وَأَقْرَأْتُهُ كُتُبَهُمْ إِذَا كَتَبُوا إِلَيْهِ، وَقَالَ عُمَرُ وَعِنْدَهُ عَلِيٌّ وَعَبْدُ الرَّحْمَنِ وَعُثْمَانُ مَاذَا تَقُولُ هَذِهِ قَالَ عَبْدُ الرَّحْمَنِ بْنُ حَاطِبٍ فَقُلْتُ تُخْبِرُكَ بِصَاحِبِهِمَا الَّذِي صَنَعَ بِهِمَا‏.‏ وَقَالَ أَبُو جَمْرَةَ كُنْتُ أُتَرْجِمُ بَيْنَ ابْنِ عَبَّاسٍ وَبَيْنَ النَّاسِ‏.‏ وَقَالَ بَعْضُ النَّاسِ لاَ بُدَّ لِلْحَاكِمِ مِنْ مُتَرْجِمَيْنِ‏.‏\hadithno{7195}\hadithtrans{Kharija bin Zaid bin Thabit said that Zaid bin Thabit said, "The Prophet (ﷺ) ordered me to learn the writing of the Jews. I even wrote letters for the Prophet (ﷺ) (to the Jews) and also read their letters when they wrote to him." And 'Umar said in the presence of 'Ali, 'Abdur-Rahman, and 'Uthman, "What is this woman saying?" (the woman was non-Arab) 'Abdur-Rahman bin Hatib said:"She is informing you about her companion who has committed illegal sexual intercourse with her." Abu Jamra said, "I was an interpreter between Ibn 'Abbas and the people." Some people said, "A ruler should have two interpreters}}
\hadithdefcmd{bukhari}{7196}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، أَخْبَرَهُ أَنَّ أَبَا سُفْيَانَ بْنَ حَرْبٍ أَخْبَرَهُ أَنَّ هِرَقْلَ أَرْسَلَ إِلَيْهِ فِي رَكْبٍ مِنْ قُرَيْشٍ، ثُمَّ قَالَ لِتَرْجُمَانِهِ قُلْ لَهُمْ إِنِّي سَائِلٌ هَذَا، فَإِنْ كَذَبَنِي فَكَذِّبُوهُ‏.‏ فَذَكَرَ الْحَدِيثَ فَقَالَ لِلتَّرْجُمَانِ قُلْ لَهُ إِنْ كَانَ مَا تَقُولُ حَقًّا فَسَيَمْلِكُ مَوْضِعَ قَدَمَىَّ هَاتَيْنِ‏.‏\hadithno{7196}\hadithtrans{Narrated `Abdullah bin `Abbas:That Abu Sufyan bin Harb told him that Heraclius had called him along with the members of a Quraish caravan and then said to his interpreter, "Tell them that I want to ask this (Abu Sufyan) a question, and if he tries to tell me a lie, they should contradict him." Then Abu Sufyan mentioned the whole narration and said that Heraclius said to the inter Peter, "Say to him (Abu Sufyan), 'If what you say is true, then he (the Prophet) will take over the place underneath my two feet}}
\hadithdefcmd{bukhari}{7197}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا عَبْدَةُ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ أَبِي حُمَيْدٍ السَّاعِدِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اسْتَعْمَلَ ابْنَ الأُتَبِيَّةِ عَلَى صَدَقَاتِ بَنِي سُلَيْمٍ، فَلَمَّا جَاءَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَحَاسَبَهُ قَالَ هَذَا الَّذِي لَكُمْ، وَهَذِهِ هَدِيَّةٌ أُهْدِيَتْ لِي‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَهَلاَّ جَلَسْتَ فِي بَيْتِ أَبِيكَ وَبَيْتِ أُمِّكَ حَتَّى تَأْتِيَكَ هَدِيَّتُكَ، إِنْ كُنْتَ صَادِقًا ‏"‏‏.‏ ثُمَّ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَخَطَبَ النَّاسَ وَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ فَإِنِّي أَسْتَعْمِلُ رِجَالاً مِنْكُمْ عَلَى أُمُورٍ مِمَّا وَلاَّنِي اللَّهُ، فَيَأْتِي أَحَدُكُمْ فَيَقُولُ هَذَا لَكُمْ وَهَذِهِ هَدِيَّةٌ أُهْدِيَتْ لِي فَهَلاَّ جَلَسَ فِي بَيْتِ أَبِيهِ وَبَيْتِ أُمِّهِ حَتَّى تَأْتِيَهُ هَدِيَّتُهُ إِنْ كَانَ صَادِقًا، فَوَاللَّهِ لاَ يَأْخُذُ أَحَدُكُمْ مِنْهَا شَيْئًا ـ قَالَ هِشَامٌ ـ بِغَيْرِ حَقِّهِ إِلاَّ جَاءَ اللَّهَ يَحْمِلُهُ يَوْمَ الْقِيَامَةِ، أَلاَ فَلأَعْرِفَنَّ مَا جَاءَ اللَّهَ رَجُلٌ بِبَعِيرٍ لَهُ رُغَاءٌ، أَوْ بِبَقَرَةٍ لَهَا خُوَارٌ، أَوْ شَاةٍ تَيْعَرُ ‏"‏‏.‏ ثُمَّ رَفَعَ يَدَيْهِ حَتَّى رَأَيْتُ بَيَاضَ إِبْطَيْهِ ‏"‏ أَلاَ هَلْ بَلَّغْتُ ‏"‏‏.‏\hadithno{7197}\hadithtrans{Narrated Abu Humaid As-Sa`idi:The Prophet (ﷺ) employed Ibn Al-Utbiyya to collect Zakat from Bani Sulaim, and when he returned (with the money) to Allah's Messenger (ﷺ) the Prophet (ﷺ) called him to account, and he said, "This (amount) is for you, and this was given to me as a present." Allah's Messenger (ﷺ) said, "Why don't you stay at your father's house or your mother's house to see whether you will be given gifts or not, if you are telling the truth?" Then Allah's Messenger (ﷺ) stood up and addressed the people, and after glorifying and praising Allah, he said: Amma Ba'du (then after) I employ some men from among you for some job which Allah has placed in my charge, and then one of you comes to me and says, 'This (amount) is for you and this is a gift given to me.' Why doesn't he stay at the house of his father or the house of his mother and see whether he will be given gifts or not if he was telling the truth by Allah, none of you takes anything of it (i.e., Zakat) for himself (Hisham added: unlawfully) but he will meet Allah on the Day of Resurrection carrying it on his neck! I do not want to see any of you carrying a grunting camel or a mooing cow or a bleating sheep on meeting Allah." Then the Prophet (ﷺ) raised both his hands till I saw the whiteness of his armpits, and said, "(No doubt)! Haven't I conveyed Allah's Message}}
\hadithdefcmd{bukhari}{7198}{حَدَّثَنَا أَصْبَغُ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا بَعَثَ اللَّهُ مِنْ نَبِيٍّ وَلاَ اسْتَخْلَفَ مِنْ خَلِيفَةٍ، إِلاَّ كَانَتْ لَهُ بِطَانَتَانِ، بِطَانَةٌ تَأْمُرُهُ بِالْمَعْرُوفِ وَتَحُضُّهُ عَلَيْهِ، وَبِطَانَةٌ تَأْمُرُهُ بِالشَّرِّ وَتَحُضُّهُ عَلَيْهِ، فَالْمَعْصُومُ مَنْ عَصَمَ اللَّهُ تَعَالَى ‏"‏‏.‏ وَقَالَ سُلَيْمَانُ عَنْ يَحْيَى أَخْبَرَنِي ابْنُ شِهَابٍ بِهَذَا، وَعَنِ ابْنِ أَبِي عَتِيقٍ وَمُوسَى عَنِ ابْنِ شِهَابٍ مِثْلَهُ، وَقَالَ شُعَيْبٌ عَنِ الزُّهْرِيِّ حَدَّثَنِي أَبُو سَلَمَةَ عَنْ أَبِي سَعِيدٍ قَوْلَهُ‏.‏ وَقَالَ الأَوْزَاعِيُّ وَمُعَاوِيَةُ بْنُ سَلاَّمٍ حَدَّثَنِي الزُّهْرِيُّ حَدَّثَنِي أَبُو سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَقَالَ ابْنُ أَبِي حُسَيْنٍ وَسَعِيدُ بْنُ زِيَادٍ عَنْ أَبِي سَلَمَةَ عَنْ أَبِي سَعِيدٍ قَوْلَهُ‏.‏ وَقَالَ عُبَيْدُ اللَّهِ بْنُ أَبِي جَعْفَرٍ حَدَّثَنِي صَفْوَانُ عَنْ أَبِي سَلَمَةَ عَنْ أَبِي أَيُّوبَ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم‏.‏\hadithno{7198}\hadithtrans{Narrated Abu Sa`id Al-Khudri:The Prophet (ﷺ) said, "Allah never sends a prophet or gives the Caliphate to a Caliph but that he (the prophet or the Caliph) has two groups of advisors: A group advising him to do good and exhorts him to do it, and the other group advising him to do evil and exhorts him to do it. But the protected person (against such evil advisors) is the one protected by Allah}}
\hadithdefcmd{bukhari}{7200}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، قَالَ أَخْبَرَنِي عُبَادَةُ بْنُ الْوَلِيدِ، أَخْبَرَنِي أَبِي، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ "بَايَعْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى السَّمْعِ وَالطَّاعَةِ فِي الْمَنْشَطِ وَالْمَكْرَهِ‏.‏ ‏‏وَأَنْ لاَ نُنَازِعَ الأَمْرَ أَهْلَهُ، وَأَنْ نَقُومَ ـ أَوْ نَقُولَ ـ بِالْحَقِّ حَيْثُمَا كُنَّا لاَ نَخَافُ فِي اللَّهِ لَوْمَةَ لاَئِمٍ ‏"‏‏.‏\hadithno{7200}\hadithtrans{Narrated 'Ubada bin As-Samit:We gave the oath of allegiance to Allah's Messenger (ﷺ) that we would listen to and obey him both at the time when we were active and at the time when we were tired and that we would not fight against the ruler or disobey him, and would stand firm for the truth or say the truth wherever we might be, and in the Way of Allah we would not be afraid of the blame of the blamers. (See Hadith No. 178 and)}}
\hadithdefcmd{bukhari}{7201}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسٍ ـ رضى الله عنه ـ خَرَجَ النَّبِيُّ صلى الله عليه وسلم فِي غَدَاةٍ بَارِدَةٍ وَالْمُهَاجِرُونَ وَالأَنْصَارُ يَحْفِرُونَ الْخَنْدَقَ فَقَالَ ‏ "‏ اللَّهُمَّ إِنَّ الْخَيْرَ خَيْرُ الآخِرَهْ فَاغْفِرْ لِلأَنْصَارِ وَالْمُهَاجِرَهْ ‏"‏ فَأَجَابُوا نَحْنُ الَّذِينَ بَايَعُوا مُحَمَّدَا عَلَى الْجِهَادِ مَا بَقِينَا أَبَدَا\hadithno{7201}\hadithtrans{Narrated Anas:The Prophet (ﷺ) went out on a cold morning while the Muhajirin (emigrants) and the Ansar were digging the trench. The Prophet (ﷺ) then said, "O Allah! The real goodness is the goodness of the Here after, so please forgive the Ansar and the Muhajirin." They replied, "We are those who have given the Pledge of allegiance to Muhammad for to observe Jihad as long as we remain alive}}
\hadithdefcmd{bukhari}{7202}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ كُنَّا إِذَا بَايَعْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى السَّمْعِ وَالطَّاعَةِ يَقُولُ لَنَا ‏ "‏ فِيمَا اسْتَطَعْتَ ‏"‏‏.‏\hadithno{7202}\hadithtrans{Narrated `Abdullah bin `Umar:Whenever we gave the Pledge of allegiance to Allah's Messenger (ﷺ) for to listen to and obey, he used to say to us, for as much as you can}}
\hadithdefcmd{bukhari}{7203}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دِينَارٍ، قَالَ شَهِدْتُ ابْنَ عُمَرَ حَيْثُ اجْتَمَعَ النَّاسُ عَلَى عَبْدِ الْمَلِكِ ـ قَالَ ـ كَتَبَ إِنِّي أُقِرُّ بِالسَّمْعِ وَالطَّاعَةِ لِعَبْدِ الْمَلِكِ أَمِيرِ الْمُؤْمِنِينَ عَلَى سُنَّةِ اللَّهِ وَسُنَّةِ رَسُولِهِ مَا اسْتَطَعْتُ، وَإِنَّ بَنِيَّ قَدْ أَقَرُّوا بِمِثْلِ ذَلِكَ‏.‏\hadithno{7203}\hadithtrans{Narrated `Abdullah bin Dinar:I witnessed Ibn `Umar when the people gathered around `Abdul Malik. Ibn `Umar wrote: I gave the Pledge of allegiance that I will listen to and obey Allah's Slave, `Abdul Malik, Chief of the believers according to Allah's Laws and the Traditions of His Apostle as much as I can; and my sons too, give the same pledge}}
\hadithdefcmd{bukhari}{7204}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا سَيَّارٌ، عَنِ الشَّعْبِيِّ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ، قَالَ بَايَعْتُ النَّبِيَّ صلى الله عليه وسلم عَلَى السَّمْعِ وَالطَّاعَةِ، فَلَقَّنَنِي، فِيمَا اسْتَطَعْتُ، وَالنُّصْحِ لِكُلِّ مُسْلِمٍ‏.‏\hadithno{7204}\hadithtrans{Narrated Jabir bin `Abdullah:I gave the Pledge of allegiance to the Prophet (ﷺ) that I would listen and obey, and he told me to add: 'As much as I can, and will give good advice to every Muslim}}
\hadithdefcmd{bukhari}{7205}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ دِينَارٍ، قَالَ لَمَّا بَايَعَ النَّاسُ عَبْدَ الْمَلِكِ كَتَبَ إِلَيْهِ عَبْدُ اللَّهِ بْنُ عُمَرَ إِلَى عَبْدِ اللَّهِ عَبْدِ الْمَلِكِ أَمِيرِ الْمُؤْمِنِينَ إِنِّي أُقِرُّ بِالسَّمْعِ وَالطَّاعَةِ لِعَبْدِ اللَّهِ عَبْدِ الْمَلِكِ أَمِيرِ الْمُؤْمِنِينَ، عَلَى سُنَّةِ اللَّهِ وَسُنَّةِ رَسُولِهِ، فِيمَا اسْتَطَعْتُ، وَإِنَّ بَنِيَّ قَدْ أَقَرُّوا بِذَلِكَ‏.‏\hadithno{7205}\hadithtrans{Narrated `Abdullah bin Dinar:When the people took the oath of allegiance to `Abdul Malik, `Abdullah bin `Umar wrote to him: "To Allah's Slave, `Abdul Malik, Chief of the believers, I give the Pledge of allegiance that I will listen to and obey Allah's Slave, `Abdul Malik, Chief of the believers, according to Allah's Laws and the Traditions of His Apostle in whatever is within my ability; and my sons too, give the same pledge}}
\hadithdefcmd{bukhari}{7206}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا حَاتِمٌ، عَنْ يَزِيدَ، قَالَ قُلْتُ لِسَلَمَةَ عَلَى أَىِّ شَىْءٍ بَايَعْتُمُ النَّبِيَّ صلى الله عليه وسلم يَوْمَ الْحُدَيْبِيَةِ قَالَ عَلَى الْمَوْتِ‏.‏\hadithno{7206}\hadithtrans{Narrated Yazid:I said to Salama, "For what did you give the Pledge of allegiance to the Prophet (ﷺ) on the Day of Hudaibiya?" He replied, "For death}}
\hadithdefcmd{bukhari}{7207}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَسْمَاءَ، حَدَّثَنَا جُوَيْرِيَةُ، عَنْ مَالِكٍ، عَنِ الزُّهْرِيِّ، أَنَّ حُمَيْدَ بْنَ عَبْدِ الرَّحْمَنِ، أَخْبَرَهُ أَنَّ الْمِسْوَرَ بْنَ مَخْرَمَةَ أَخْبَرَهُ‏.‏ أَنَّ الرَّهْطَ الَّذِينَ وَلاَّهُمْ عُمَرُ اجْتَمَعُوا فَتَشَاوَرُوا، قَالَ لَهُمْ عَبْدُ الرَّحْمَنِ لَسْتُ بِالَّذِي أُنَافِسُكُمْ عَلَى هَذَا الأَمْرِ، وَلَكِنَّكُمْ إِنْ شِئْتُمُ اخْتَرْتُ لَكُمْ مِنْكُمْ‏.‏ فَجَعَلُوا ذَلِكَ إِلَى عَبْدِ الرَّحْمَنِ، فَلَمَّا وَلَّوْا عَبْدَ الرَّحْمَنِ أَمْرَهُمْ فَمَالَ النَّاسُ عَلَى عَبْدِ الرَّحْمَنِ، حَتَّى مَا أَرَى أَحَدًا مِنَ النَّاسِ يَتْبَعُ أُولَئِكَ الرَّهْطَ وَلاَ يَطَأُ عَقِبَهُ، وَمَالَ النَّاسُ عَلَى عَبْدِ الرَّحْمَنِ يُشَاوِرُونَهُ تِلْكَ اللَّيَالِيَ حَتَّى إِذَا كَانَتِ اللَّيْلَةُ الَّتِي أَصْبَحْنَا مِنْهَا، فَبَايَعْنَا عُثْمَانَ قَالَ الْمِسْوَرُ طَرَقَنِي عَبْدُ الرَّحْمَنِ بَعْدَ هَجْعٍ مِنَ اللَّيْلِ فَضَرَبَ الْبَابَ حَتَّى اسْتَيْقَظْتُ فَقَالَ أَرَاكَ نَائِمًا، فَوَاللَّهِ مَا اكْتَحَلْتُ هَذِهِ اللَّيْلَةَ بِكَبِيرِ نَوْمٍ، انْطَلِقْ فَادْعُ الزُّبَيْرَ وَسَعْدًا، فَدَعَوْتُهُمَا لَهُ فَشَاوَرَهُمَا ثُمَّ دَعَانِي فَقَالَ ادْعُ لِي عَلِيًّا‏.‏ فَدَعَوْتُهُ فَنَاجَاهُ حَتَّى ابْهَارَّ اللَّيْلُ، ثُمَّ قَامَ عَلِيٌّ مِنْ عِنْدِهِ، وَهْوَ عَلَى طَمَعٍ، وَقَدْ كَانَ عَبْدُ الرَّحْمَنِ يَخْشَى مِنْ عَلِيٍّ شَيْئًا، ثُمَّ قَالَ ادْعُ لِي عُثْمَانَ، فَدَعَوْتُهُ فَنَاجَاهُ حَتَّى فَرَّقَ بَيْنَهُمَا الْمُؤَذِّنُ بِالصُّبْحِ، فَلَمَّا صَلَّى لِلنَّاسِ الصُّبْحَ وَاجْتَمَعَ أُولَئِكَ الرَّهْطُ عِنْدَ الْمِنْبَرِ، فَأَرْسَلَ إِلَى مَنْ كَانَ حَاضِرًا مِنَ الْمُهَاجِرِينَ وَالأَنْصَارِ، وَأَرْسَلَ إِلَى أُمَرَاءِ الأَجْنَادِ وَكَانُوا وَافَوْا تِلْكَ الْحَجَّةَ مَعَ عُمَرَ، فَلَمَّا اجْتَمَعُوا تَشَهَّدَ عَبْدُ الرَّحْمَنِ ثُمَّ قَالَ أَمَّا بَعْدُ يَا عَلِيُّ، إِنِّي قَدْ نَظَرْتُ فِي أَمْرِ النَّاسِ فَلَمْ أَرَهُمْ يَعْدِلُونَ بِعُثْمَانَ، فَلاَ تَجْعَلَنَّ عَلَى نَفْسِكَ سَبِيلاً‏.‏ فَقَالَ أُبَايِعُكَ عَلَى سُنَّةِ اللَّهِ وَرَسُولِهِ وَالْخَلِيفَتَيْنِ مِنْ بَعْدِهِ‏.‏ فَبَايَعَهُ عَبْدُ الرَّحْمَنِ، وَبَايَعَهُ النَّاسُ الْمُهَاجِرُونَ وَالأَنْصَارُ وَأُمَرَاءُ الأَجْنَادِ وَالْمُسْلِمُونَ‏.‏\hadithno{7207}\hadithtrans{Narrated Al-Miswar bin Makhrama:The group of people whom `Umar had selected as candidates for the Caliphate gathered and consulted each other. `Abdur-Rahman said to them, "I am not going to compete with you in this matter, but if you wish, I would select for you a caliph from among you." So all of them agreed to let `Abdur-Rahman decide the case. So when the candidates placed the case in the hands of `Abdur-Rahman, the people went towards him and nobody followed the rest of the group nor obeyed any after him. So the people followed `Abdur-Rahman and consulted him all those nights till there came the night we gave the oath of allegiance to `Uthman. Al-Miswar (bin Makhrama) added: `Abdur-Rahman called on me after a portion of the night had passed and knocked on my door till I got up, and he said to me, "I see you have been sleeping! By Allah, during the last three nights I have not slept enough. Go and call Az-Zubair and Sa`d.' So I called them for him and he consulted them and then called me saying, 'Call `Ali for me." I called `Ali and he held a private talk with him till very late at night, and then 'Al, got up to leave having had much hope (to be chosen as a Caliph) but `Abdur-Rahman was afraid of something concerning `Ali. `Abdur-Rahman then said to me, "Call `Uthman for me." I called him and he kept on speaking to him privately till the Mu'adh-dhin put an end to their talk by announcing the Adhan for the Fajr prayer. When the people finished their morning prayer and that (six men) group gathered near the pulpit, `Abdur-Rahman sent for all the Muhajirin (emigrants) and the Ansar present there and sent for the army chief who had performed the Hajj with `Umar that year. When all of them had gathered, `Abdur- Rahman said, "None has the right to be worshipped but Allah," and added, "Now then, O `Ali, I have looked at the people's tendencies and noticed that they do not consider anybody equal to `Uthman, so you should not incur blame (by disagreeing)." Then `Abdur-Rahman said (to `Uthman), "I gave the oath of allegiance to you on condition that you will follow Allah's Laws and the traditions of Allah's Apostle and the traditions of the two Caliphs after him." So `Abdur-Rahman gave the oath of allegiance to him, and so did the people including the Muhajirin (emigrants) and the Ansar and the chiefs of the army staff and all the Muslims}}
\hadithdefcmd{bukhari}{7208}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ يَزِيدَ بْنِ أَبِي عُبَيْدٍ، عَنْ سَلَمَةَ، قَالَ بَايَعْنَا النَّبِيَّ صلى الله عليه وسلم تَحْتَ الشَّجَرَةِ فَقَالَ لِي ‏"‏ يَا سَلَمَةُ أَلاَ تُبَايِعُ ‏"‏‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ قَدْ بَايَعْتُ فِي الأَوَّلِ‏.‏ قَالَ ‏"‏ وَفِي الثَّانِي ‏"‏‏.‏\hadithno{7208}\hadithtrans{Narrated Salama:We gave the oath of allegiance to the Prophet (ﷺ) under the tree. He said to me, "O Salama! Will you not give the oath of allegiance?" I replied, "O Allah's Messenger (ﷺ)! I have already given the oath of allegiance for the first time." He said, (Give it again) for the second time}}
\hadithdefcmd{bukhari}{7209}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ أَنَّ أَعْرَابِيًّا بَايَعَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى الإِسْلاَمِ، فَأَصَابَهُ وَعْكٌ فَقَالَ أَقِلْنِي بَيْعَتِي‏.‏ فَأَبَى، ثُمَّ جَاءَهُ فَقَالَ أَقِلْنِي بَيْعَتِي‏.‏ فَأَبَى، فَخَرَجَ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمَدِينَةُ كَالْكِيرِ، تَنْفِي خَبَثَهَا، وَيَنْصَعُ طِيبُهَا ‏"‏‏.‏\hadithno{7209}\hadithtrans{Narrated Jabir bin `Abdullah:A bedouin gave the Pledge of allegiance to Allah's Messenger (ﷺ) for Islam and the bedouin got a fever where upon he said to the Prophet (ﷺ) "Cancel my Pledge." But the Prophet (ﷺ) refused. He came to him (again) saying, "Cancel my Pledge.' But the Prophet (ﷺ) refused. Then (the bedouin) left (Medina). Allah's Apostle said: "Medina is like a pair of bellows (furnace): It expels its impurities and brightens and clears its good}}
\hadithdefcmd{bukhari}{7210}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، حَدَّثَنَا سَعِيدٌ ـ هُوَ ابْنُ أَبِي أَيُّوبَ ـ قَالَ حَدَّثَنِي أَبُو عَقِيلٍ، زُهْرَةُ بْنُ مَعْبَدٍ عَنْ جَدِّهِ عَبْدِ اللَّهِ بْنِ هِشَامٍ، وَكَانَ، قَدْ أَدْرَكَ النَّبِيَّ صلى الله عليه وسلم وَذَهَبَتْ بِهِ أُمُّهُ زَيْنَبُ ابْنَةُ حُمَيْدٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ بَايِعْهُ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ هُوَ صَغِيرٌ ‏"‏ فَمَسَحَ رَأْسَهُ وَدَعَا لَهُ، وَكَانَ يُضَحِّي بِالشَّاةِ الْوَاحِدَةِ عَنْ جَمِيعِ أَهْلِهِ‏.‏\hadithno{7210}\hadithtrans{Narrated `Abdullah bin Hisham:who was born during the lifetime of the Prophet (ﷺ) that his mother, Zainab bint Humaid had taken him to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! Take his Pledge of allegiance (for Islam)." The Prophet (ﷺ) said, "He (`Abdullah bin Hisham) is a little child," and passed his hand over his head and invoked Allah for him. `Abdullah bin Hisham used to slaughter one sheep as a sacrifice on behalf of all of his family}}
\hadithdefcmd{bukhari}{7211}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ،‏.‏ أَنَّ أَعْرَابِيًّا، بَايَعَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى الإِسْلاَمِ فَأَصَابَ الأَعْرَابِيَّ وَعْكٌ بِالْمَدِينَةِ، فَأَتَى الأَعْرَابِيُّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أَقِلْنِي بَيْعَتِي، فَأَبَى رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ جَاءَهُ فَقَالَ أَقِلْنِي بَيْعَتِي فَأَبَى، ثُمَّ جَاءَهُ فَقَالَ أَقِلْنِي بَيْعَتِي فَأَبَى فَخَرَجَ الأَعْرَابِيُّ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا الْمَدِينَةُ كَالْكِيرِ تَنْفِي خَبَثَهَا وَيَنْصَعُ طِيبُهَا ‏"‏‏.‏\hadithno{7211}\hadithtrans{Narrated Jabir bin `Abdullah:A bedouin gave the Pledge of allegiance to Allah's Messenger (ﷺ) for Islam. Then the bedouin got fever at Medina, came to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! Cancel my Pledge," But Allah's Apostle refused. Then he came to him (again) and said, "O Allah's Messenger (ﷺ)! Cancel my Pledge." But the Prophet (ﷺ) refused Then he came to him (again) and said, "O Allah's Messenger (ﷺ)! Cancel my Pledge." But the Prophet (ﷺ) refused. The bedouin finally went out (of Medina) whereupon Allah's Messenger (ﷺ) said, "Medina is like a pair of bellows (furnace): It expels its impurities and brightens and clears its good}}
\hadithdefcmd{bukhari}{7212}{حَدَّثَنَا عَبْدَانُ، عَنْ أَبِي حَمْزَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ثَلاَثَةٌ لاَ يُكَلِّمُهُمُ اللَّهُ يَوْمَ الْقِيَامَةِ، وَلاَ يُزَكِّيهِمْ، وَلَهُمْ عَذَابٌ أَلِيمٌ رَجُلٌ عَلَى فَضْلِ مَاءٍ بِالطَّرِيقِ يَمْنَعُ مِنْهُ ابْنَ السَّبِيلِ، وَرَجُلٌ بَايَعَ إِمَامًا لاَ يُبَايِعُهُ إِلاَّ لِدُنْيَاهُ، إِنْ أَعْطَاهُ مَا يُرِيدُ وَفَى لَهُ، وَإِلاَّ لَمْ يَفِ لَهُ، وَرَجُلٌ يُبَايِعُ رَجُلاً بِسِلْعَةٍ بَعْدَ الْعَصْرِ فَحَلَفَ بِاللَّهِ لَقَدْ أُعْطِيَ بِهَا كَذَا وَكَذَا فَصَدَّقَهُ، فَأَخَذَهَا، وَلَمْ يُعْطَ بِهَا ‏"‏‏.‏\hadithno{7212}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "There will be three types of people whom Allah will neither speak to them on the Day of Resurrection nor will purify them from sins, and they will have a painful punishment: They are, (1) a man possessed superfluous water (more than he needs) on a way and he withholds it from the travelers. (2) a man who gives a pledge of allegiance to an Imam (ruler) and gives it only for worldly benefits, if the Imam gives him what he wants, he abides by his pledge, otherwise he does not fulfill his pledge; (3) and a man who sells something to another man after the `Asr prayer and swears by Allah (a false oath) that he has been offered so much for it whereupon the buyer believes him and buys it although in fact, the seller has not been offered such a price." (See Hadith No. 838, Vol)}}
\hadithdefcmd{bukhari}{7213}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، وَقَالَ اللَّيْثُ، حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي أَبُو إِدْرِيسَ الْخَوْلاَنِيُّ، أَنَّهُ سَمِعَ عُبَادَةَ بْنَ الصَّامِتِ، يَقُولُ قَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَحْنُ فِي مَجْلِسٍ ‏ "‏ تُبَايِعُونِي عَلَى أَنْ لاَ تُشْرِكُوا بِاللَّهِ شَيْئًا، وَلاَ تَسْرِقُوا، وَلاَ تَزْنُوا، وَلاَ تَقْتُلُوا أَوْلاَدَكُمْ، وَلاَ تَأْتُوا بِبُهْتَانٍ تَفْتَرُونَهُ بَيْنَ أَيْدِيكُمْ وَأَرْجُلِكُمْ وَلاَ تَعْصُوا فِي مَعْرُوفٍ، فَمَنْ وَفَى مِنْكُمْ فَأَجْرُهُ عَلَى اللَّهِ، وَمَنْ أَصَابَ مِنْ ذَلِكَ شَيْئًا فَعُوقِبَ فِي الدُّنْيَا فَهْوَ كَفَّارَةٌ لَهُ، وَمَنْ أَصَابَ مِنْ ذَلِكَ شَيْئًا فَسَتَرَهُ اللَّهُ فَأَمْرُهُ إِلَى اللَّهِ إِنْ شَاءَ عَاقَبَهُ وَإِنْ شَاءَ عَفَا عَنْهُ ‏"‏، فَبَايَعْنَاهُ عَلَى ذَلِكَ‏.‏\hadithno{7213}\hadithtrans{Narrated 'Ubada bin As-Samit:Allah's Messenger (ﷺ) said to us while we were in a gathering, "Give me the oath (Pledge of allegiance for: (1) Not to join anything in worship along with Allah, (2) Not to steal, (3) Not to commit illegal sexual intercourse, (4) Not to kill your children, (5) Not to accuse an innocent person (to spread such an accusation among people), (6) Not to be disobedient (when ordered) to do good deeds. The Prophet (ﷺ) added: Whoever amongst you fulfill his pledge, his reward will be with Allah, and whoever commits any of those sins and receives the legal punishment in this world for that sin, then that punishment will be an expiation for that sin, and whoever commits any of those sins and Allah does not expose him, then it is up to Allah if He wishes He will punish him or if He wishes, He will forgive him." So we gave the Pledge for that. (See Hadith No. 17, Vol)}}
\hadithdefcmd{bukhari}{7214}{حَدَّثَنَا مَحْمُودٌ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُبَايِعُ النِّسَاءَ بِالْكَلاَمِ بِهَذِهِ الآيَةِ ‏\{‏لاَ يُشْرِكْنَ بِاللَّهِ شَيْئًا‏\}‏ قَالَتْ وَمَا مَسَّتْ يَدُ رَسُولِ اللَّهِ صلى الله عليه وسلم يَدَ امْرَأَةٍ، إِلاَّ امْرَأَةً يَمْلِكُهَا‏.‏\hadithno{7214}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to take the Pledge of allegiance from the women by words only after reciting this Holy Verse:--(60.12) "..that they will not associate anything in worship with Allah." (60.12) And the hand of Allah's Messenger (ﷺ) did not touch any woman's hand except the hand of that woman his right hand possessed. (i.e. his captives or his lady slaves)}}
\hadithdefcmd{bukhari}{7215}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ أَيُّوبَ، عَنْ حَفْصَةَ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ بَايَعْنَا النَّبِيَّ صلى الله عليه وسلم فَقَرَأَ عَلَىَّ ‏\{‏أَنْ لاَ يُشْرِكْنَ بِاللَّهِ شَيْئًا‏\}‏ وَنَهَانَا عَنِ النِّيَاحَةِ، فَقَبَضَتِ امْرَأَةٌ مِنَّا يَدَهَا فَقَالَتْ فُلاَنَةُ أَسْعَدَتْنِي وَأَنَا أُرِيدُ أَنْ أَجْزِيَهَا، فَلَمْ يَقُلْ شَيْئًا، ثُمَّ رَجَعَتْ، فَمَا وَفَتِ امْرَأَةٌ إِلاَّ أُمُّ سُلَيْمٍ وَأُمُّ الْعَلاَءِ، وَابْنَةُ أَبِي سَبْرَةَ امْرَأَةُ مُعَاذٍ أَوِ ابْنَةُ أَبِي سَبْرَةَ وَامْرَأَةُ مُعَاذٍ‏.‏\hadithno{7215}\hadithtrans{Narrated Um Atiyya:We gave the Pledge of allegiance to the Prophet (ﷺ) and he recited to me the verse (60.12). That they will not associate anything in worship with Allah (60.12). And he also prevented us from wailing and lamenting over the dead. A woman from us held her hand out and said, "Such-and-such a woman cried over a dead person belonging to my family and I want to compensate her for that crying" The Prophet did not say anything in reply and she left and returned. None of those women abided by her pledge except Um Sulaim, Um Al-`Ala', and the daughter of Abi Sabra, the wife of Al-Mu`adh or the daughter of Abi Sabra, and the wife of Mu`adh}}
\hadithdefcmd{bukhari}{7216}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، سَمِعْتُ جَابِرًا، قَالَ جَاءَ أَعْرَابِيٌّ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ بَايِعْنِي عَلَى الإِسْلاَمِ‏.‏ فَبَايَعَهُ عَلَى الإِسْلاَمِ، ثُمَّ جَاءَ الْغَدَ مَحْمُومًا فَقَالَ أَقِلْنِي‏.‏ فَأَبَى، فَلَمَّا وَلَّى قَالَ ‏ "‏ الْمَدِينَةُ كَالْكِيرِ، تَنْفِي خَبَثَهَا، وَيَنْصَعُ طِيبُهَا ‏"‏‏.‏\hadithno{7216}\hadithtrans{Narrated Jabir:A bedouin came to the Prophet (ﷺ) and said, "Please take my Pledge of allegiance for Islam." So the Prophet took from him the Pledge of allegiance for Islam. He came the next day with a fever and said to the Prophet (ﷺ) "Cancel my pledge." But the Prophet (ﷺ) refused and when the bedouin went away, the Prophet said, "Medina is like a pair of bellows (furnace): It expels its impurities and brightens and clears its good}}
\hadithdefcmd{bukhari}{7217}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، سَمِعْتُ الْقَاسِمَ بْنَ مُحَمَّدٍ، قَالَ قَالَتْ عَائِشَةُ ـ رضى الله عنها ـ وَارَأْسَاهْ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ذَاكِ لَوْ كَانَ وَأَنَا حَىٌّ فَأَسْتَغْفِرُ لَكِ وَأَدْعُو لَكِ ‏"‏‏.‏ فَقَالَتْ عَائِشَةُ وَاثُكْلِيَاهْ وَاللَّهِ إِنِّي لأَظُنُّكَ تُحِبُّ مَوْتِي وَلَوْ كَانَ ذَاكَ لَظَلِلْتَ آخِرَ يَوْمِكَ مُعَرِّسًا بِبَعْضِ أَزْوَاجِكَ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ بَلْ أَنَا وَارَأْسَاهْ لَقَدْ هَمَمْتُ ـ أَوْ أَرَدْتُ ـ أَنْ أُرْسِلَ إِلَى أَبِي بَكْرٍ وَابْنِهِ فَأَعْهَدَ أَنْ يَقُولَ الْقَائِلُونَ أَوْ يَتَمَنَّى الْمُتَمَنُّونَ ‏"‏‏.‏ ثُمَّ قُلْتُ يَأْبَى اللَّهُ وَيَدْفَعُ الْمُؤْمِنُونَ، أَوْ يَدْفَعُ اللَّهُ وَيَأْبَى الْمُؤْمِنُونَ‏.‏\hadithno{7217}\hadithtrans{Narrated Al-Qasim bin Muhammad:`Aisha said, "O my head!" Allah's Messenger (ﷺ) said, "If that (i.e., your death) should happen while I am still alive, I would ask Allah to forgive you and would invoke Allah for you." `Aisha said, "O my life which is going to be lost! By Allah, I think that you wish for my death, and if that should happen then you would be busy enjoying the company of one of your wives in the last part of that day." The Prophet said, "But I should say, 'O my head!' I feel like calling Abu Bakr and his son and appoint (the former as my successors lest people should say something or wish for something. Allah will insist (on Abu Bakr becoming a Caliph) and the believers will prevent (anyone else from claiming the Caliphate)," or "..Allah will prevent (anyone else from claiming the Caliphate) and the believers will insist (on Abu Bakr becoming the Caliph)}}
\hadithdefcmd{bukhari}{7218}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، أَخْبَرَنَا سُفْيَانُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ قِيلَ لِعُمَرَ أَلاَ تَسْتَخْلِفُ قَالَ إِنْ أَسْتَخْلِفْ فَقَدِ اسْتَخْلَفَ مَنْ هُوَ خَيْرٌ مِنِّي أَبُو بَكْرٍ، وَإِنْ أَتْرُكْ فَقَدْ تَرَكَ مَنْ هُوَ خَيْرٌ مِنِّي رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَثْنَوْا عَلَيْهِ فَقَالَ رَاغِبٌ رَاهِبٌ، وَدِدْتُ أَنِّي نَجَوْتُ مِنْهَا كَفَافًا لاَ لِي وَلاَ عَلَىَّ لاَ أَتَحَمَّلُهَا حَيًّا وَمَيِّتًا‏.‏\hadithno{7218}\hadithtrans{Narrated `Abdullah bin `Umar:It was said to `Umar, "Will you appoint your successor?" `Umar said, "If I appoint a Caliph (as my successor) it is true that somebody who was better than I (i.e., Abu Bakr) did so, and if I leave the matter undecided, it is true that somebody who was better than I (i.e., Allah's Messenger (ﷺ)) did so." On this, the people praised him. `Umar said, "People are of two kinds: Either one who is keen to take over the Caliphate or one who is afraid of assuming such a responsibility. I wish I could be free from its responsibility in that I would receive neither reward nor retribution I won't bear the burden of the caliphate in my death as I do in my life}}
\hadithdefcmd{bukhari}{7219}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامٌ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي أَنَسُ بْنُ مَالِكٍ ـ رضى الله عنه ـ أَنَّهُ سَمِعَ خُطْبَةَ، عُمَرَ الآخِرَةَ حِينَ جَلَسَ عَلَى الْمِنْبَرِ، وَذَلِكَ الْغَدُ مِنْ يَوْمٍ تُوُفِّيَ النَّبِيُّ صلى الله عليه وسلم فَتَشَهَّدَ وَأَبُو بَكْرٍ صَامِتٌ لاَ يَتَكَلَّمُ قَالَ كُنْتُ أَرْجُو أَنْ يَعِيشَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى يَدْبُرَنَا ـ يُرِيدُ بِذَلِكَ أَنْ يَكُونَ آخِرَهُمْ ـ فَإِنْ يَكُ مُحَمَّدٌ صلى الله عليه وسلم قَدْ مَاتَ، فَإِنَّ اللَّهَ تَعَالَى قَدْ جَعَلَ بَيْنَ أَظْهُرِكُمْ نُورًا تَهْتَدُونَ بِهِ بِمَا هَدَى اللَّهُ مُحَمَّدًا صلى الله عليه وسلم وَإِنَّ أَبَا بَكْرٍ صَاحِبُ رَسُولِ اللَّهِ صلى الله عليه وسلم ثَانِي اثْنَيْنِ، فَإِنَّهُ أَوْلَى الْمُسْلِمِينَ بِأُمُورِكُمْ، فَقُومُوا فَبَايِعُوهُ‏.‏ وَكَانَتْ طَائِفَةٌ مِنْهُمْ قَدْ بَايَعُوهُ قَبْلَ ذَلِكَ فِي سَقِيفَةِ بَنِي سَاعِدَةَ، وَكَانَتْ بَيْعَةُ الْعَامَّةِ عَلَى الْمِنْبَرِ‏.‏ قَالَ الزُّهْرِيُّ عَنْ أَنَسِ بْنِ مَالِكٍ سَمِعْتُ عُمَرَ يَقُولُ لأَبِي بَكْرٍ يَوْمَئِذٍ اصْعَدِ الْمِنْبَرَ‏.‏ فَلَمْ يَزَلْ بِهِ حَتَّى صَعِدَ الْمِنْبَرَ، فَبَايَعَهُ النَّاسُ عَامَّةً‏.‏\hadithno{7219}\hadithtrans{Narrated Anas bin Malik:That he heard `Umar's second speech he delivered when he sat on the pulpit on the day following the death of the Prophet (ﷺ) `Umar recited the Tashahhud while Abu Bakr was silent. `Umar said, "I wish that Allah's Messenger (ﷺ) had outlived all of us, i.e., had been the last (to die). But if Muhammad is dead, Allah nevertheless has kept the light amongst you from which you can receive the same guidance as Allah guided Muhammad with that. And Abu Bakr is the companion of Allah's Messenger (ﷺ) He is the second of the two in the cave. He is the most entitled person among the Muslims to manage your affairs. Therefore get up and swear allegiance to him." Some people had already taken the oath of allegiance to him in the shed of Bani Sa`ida but the oath of allegiance taken by the public was taken at the pulpit. I heard `Umar saying to Abu Bakr on that day. "Please ascend the pulpit," and kept on urging him till he ascended the pulpit whereupon, all the people swore allegiance to him}}
\hadithdefcmd{bukhari}{7220}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ مُحَمَّدِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ أَبِيهِ، قَالَ أَتَتِ النَّبِيَّ صلى الله عليه وسلم امْرَأَةٌ فَكَلَّمَتْهُ فِي شَىْءٍ فَأَمَرَهَا أَنْ تَرْجِعَ إِلَيْهِ، قَالَتْ يَا رَسُولَ اللَّهِ أَرَأَيْتَ إِنْ جِئْتُ وَلَمْ أَجِدْكَ، كَأَنَّهَا تُرِيدُ الْمَوْتَ، قَالَ ‏ "‏ إِنْ لَمْ تَجِدِينِي فَأْتِي أَبَا بَكْرٍ ‏"‏‏.‏\hadithno{7220}\hadithtrans{Narrated Jubair bin Mut`im:A woman came to the Prophet (ﷺ) and spoke to him about something and he told her to return to him. She said, "O Allah's Messenger (ﷺ)! If I come and do not find you?" (As if she meant, "...if you die?") The Prophet said, "If you should not find me, then go to Abu Bakr}}
\hadithdefcmd{bukhari}{7221}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، حَدَّثَنِي قَيْسُ بْنُ مُسْلِمٍ، عَنْ طَارِقِ بْنِ شِهَابٍ، عَنْ أَبِي بَكْرٍ ـ رضى الله عنه ـ قَالَ لِوَفْدِ بُزَاخَةَ تَتْبَعُونَ أَذْنَابَ الإِبِلِ حَتَّى يُرِيَ اللَّهُ خَلِيفَةَ نَبِيِّهِ صلى الله عليه وسلم وَالْمُهَاجِرِينَ أَمْرًا يَعْذِرُونَكُمْ بِهِ‏.‏\hadithno{7221}\hadithtrans{Narrated Tariq bin Shihab:Abu Bakr said to the delegate of Buzakha. "Follow the tails of the camels till Allah shows the Caliph (successor) of His Prophet and Al-Muhajirin (emigrants) something because of which you may excuse yourselves}}
\hadithdefcmd{bukhari}{7223}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْمَلِكِ، سَمِعْتُ جَابِرَ بْنَ سَمُرَةَ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ يَكُونُ اثْنَا عَشَرَ أَمِيرًا ـ فَقَالَ كَلِمَةً لَمْ أَسْمَعْهَا فَقَالَ أَبِي إِنَّهُ قَالَ ـ كُلُّهُمْ مِنْ قُرَيْشٍ ‏"‏‏.‏\hadithno{7223}\hadithtrans{Narrated Jabir bin Samura:I heard the Prophet (ﷺ) saying, "There will be twelve Muslim rulers (who will rule all the Islamic world)." He then said a sentence which I did not hear. My father said, "All of them (those rulers) will be from Quraish}}
\hadithdefcmd{bukhari}{7224}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لَقَدْ هَمَمْتُ أَنْ آمُرَ بِحَطَبٍ يُحْتَطَبُ، ثُمَّ آمُرَ بِالصَّلاَةِ فَيُؤَذَّنَ لَهَا، ثُمَّ آمُرَ رَجُلاً فَيَؤُمَّ النَّاسَ، ثُمَّ أُخَالِفَ إِلَى رِجَالٍ فَأُحَرِّقَ عَلَيْهِمْ بُيُوتَهُمْ، وَالَّذِي نَفْسِي بِيَدِهِ لَوْ يَعْلَمُ أَحَدُكُمْ أَنَّهُ يَجِدُ عَرْقًا سَمِينًا أَوْ مَرْمَاتَيْنِ حَسَنَتَيْنِ لَشَهِدَ الْعِشَاءَ ‏"‏‏.‏ قَالَ مُحَمَّدُ بْنُ يُوسُفَ قَالَ يُونُسُ قَالَ مُحَمَّدُ بْنُ سُلَيْمَانَ قَالَ أَبُو عَبْدِ اللَّهِ مِرْمَاةٌ مَا بَيْنَ ظِلْفِ الشَّاةِ مِنَ اللَّحْمِ مِثْلُ مِنْسَاةٍ وَمِيضَاةٍ‏.‏ الْمِيمُ مَخْفُوضَةٌ‏.‏\hadithno{7224}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "By Him in Whose Hands my life is, I was about to order for collecting fire wood and then order someone to pronounce the Adhan for the prayer and then order someone to lead the people in prayer and then I would go from behind and burn the houses of men who did not present themselves for the (compulsory congregational) prayer. By Him in Whose Hands my life is, if anyone of you had known that he would receive a bone covered with meat or two (small) pieces of meat present in between two ribs, he would come for `Isha' prayer." (See Hadith No. 617, Vol)}}
\hadithdefcmd{bukhari}{7225}{حَدَّثَنِي يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ، أَنَّ عَبْدَ اللَّهِ بْنَ كَعْبِ بْنِ مَالِكٍ ـ وَكَانَ قَائِدَ كَعْبٍ مِنْ بَنِيهِ حِينَ عَمِيَ ـ قَالَ سَمِعْتُ كَعْبَ بْنَ مَالِكٍ، قَالَ لَمَّا تَخَلَّفَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةِ تَبُوكَ ـ فَذَكَرَ حَدِيثَهُ ـ وَنَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم الْمُسْلِمِينَ عَنْ كَلاَمِنَا، فَلَبِثْنَا عَلَى ذَلِكَ خَمْسِينَ لَيْلَةً، وَآذَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِتَوْبَةِ اللَّهِ عَلَيْنَا‏.‏\hadithno{7225}\hadithtrans{Narrated `Abdullah bin Ka`b bin Malik:Who was Ka`b's guide from among his sons when Ka`b became blind: I heard Ka`b bin Malik saying, "When some people remained behind and did not join Allah's Messenger (ﷺ) in the battle of Tabuk.." and then he described the whole narration and said, "Allah's Messenger (ﷺ) forbade the Muslims to speak to us, and so we (I and my companions) stayed fifty nights in that state, and then Allah's Messenger (ﷺ) announced Allah's acceptance of our repentance}}
